#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
@Time    ：2020/9/3 18:33
@Author  ：维斯
@File    ：tool_random.py
@Version ：1.0
@Function：随机工具
    一、生成指定长度的随机值
        1、数字
        2、小写字母
        3、大小字母
        4、小写+大写
        5、字母(小、大)+数字
        6、数字+小写
        7、数字+大写
    二、生成随机IP地址
"""

import random


class PyUtilRandom:
    NUMBER = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '0']
    LOWER = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u',
             'v', 'w', 'x', 'y', 'z']
    UPPER = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U',
             'V', 'W', 'X', 'Y', 'Z']
    LOWER_UPPER = LOWER + UPPER
    NUMBER_LOWER_UPPER = NUMBER + LOWER_UPPER
    NUMBER_LOWER = NUMBER + LOWER
    NUMBER_UPPER = NUMBER + UPPER
    NAME_XING = ['赵', '钱', '孙', '李', '周', '吴', '郑', '王', '冯', '陈', '褚', '卫', '蒋', '沈', '韩', '杨', '朱', '秦', '尤', '许',
                 '何', '吕', '施', '张', '孔', '曹', '严', '华', '金', '魏', '陶', '姜', '戚', '谢', '邹', '喻', '柏', '水', '窦', '章',
                 '云', '苏', '潘', '葛', '奚', '范', '彭', '郎', '鲁', '韦', '昌', '马', '苗', '凤', '花', '方', '俞', '任', '袁', '柳',
                 '酆', '鲍', '史', '唐', '费', '廉', '岑', '薛', '雷', '贺', '倪', '汤', '滕', '殷', '罗', '毕', '郝', '邬', '安', '常',
                 '乐', '于', '时', '傅', '皮', '卞', '齐', '康', '伍', '余', '元', '卜', '顾', '孟', '平', '黄', '和', '穆', '萧', '尹',
                 '姚', '邵', '湛', '汪', '祁', '毛', '禹', '狄', '米', '贝', '明', '臧', '计', '伏', '成', '戴', '谈', '宋', '茅', '庞',
                 '熊', '纪', '舒', '屈', '项', '祝', '董', '梁', '杜', '阮', '蓝', '闵', '席', '季', '麻', '强', '贾', '路', '娄', '危',
                 '江', '童', '颜', '郭', '梅', '盛', '林', '刁', '锺', '徐', '丘', '骆', '高', '夏', '蔡', '田', '樊', '胡', '凌', '霍',
                 '虞', '万', '支', '柯', '昝', '管', '卢', '莫', '经', '房', '裘', '缪', '干', '解', '应', '宗', '丁', '宣', '贲', '邓',
                 '郁', '单', '杭', '洪', '包', '诸', '左', '石', '崔', '吉', '钮', '龚', '程', '嵇', '邢', '滑', '裴', '陆', '荣', '翁',
                 '荀', '羊', '於', '惠', '甄', '麹', '家', '封', '芮', '羿', '储', '靳', '汲', '邴', '糜', '松', '井', '段', '富', '巫',
                 '乌', '焦', '巴', '弓', '牧', '隗', '山', '谷', '车', '侯', '宓', '蓬', '全', '郗', '班', '仰', '秋', '仲', '伊', '宫',
                 '甯', '仇', '栾', '暴', '甘', '钭', '厉', '戎', '祖', '武', '符', '刘', '景', '詹', '束', '龙', '叶', '幸', '司', '韶',
                 '郜', '黎', '蓟', '薄', '印', '宿', '白', '怀', '蒲', '邰', '从', '鄂', '索', '咸', '籍', '赖', '卓', '蔺', '屠', '蒙',
                 '池', '乔', '阴', '鬱', '胥', '能', '苍', '双', '闻', '莘', '党', '翟', '谭', '贡', '劳', '逄', '姬', '申', '扶', '堵',
                 '冉', '宰', '郦', '雍', '郤', '璩', '桑', '桂', '濮', '牛', '寿', '通', '边', '扈', '燕', '冀', '郏', '浦', '尚', '农',
                 '温', '别', '庄', '晏', '柴', '瞿', '阎', '充', '慕', '连', '茹', '习', '宦', '艾', '鱼', '容', '向', '古', '易', '慎',
                 '戈', '廖', '庾', '终', '暨', '居', '衡', '步', '都', '耿', '满', '弘', '匡', '国', '文', '寇', '广', '禄', '阙', '东',
                 '欧', '殳', '沃', '利', '蔚', '越', '夔', '隆', '师', '巩', '厍', '聂', '晁', '勾', '敖', '融', '冷', '訾', '辛', '阚',
                 '那', '简', '饶', '空', '曾', '毋', '沙', '乜', '养', '鞠', '须', '丰', '巢', '关', '蒯', '相', '查', '后', '荆', '红',
                 '游', '竺', '权', '逯', '盖', '益', '桓', '公', '万俟', '司马', '上官', '欧阳', '夏侯', '诸葛', '闻人', '东方', '赫连', '皇甫',
                 '尉迟', '公羊', '澹台', '公冶', '宗政', '濮阳', '淳于', '单于', '太叔', '申屠', '公孙', '仲孙', '轩辕', '令狐', '锺离', '宇文',
                 '长孙', '慕容', '鲜于', '闾丘', '司徒', '司空', '亓官', '司寇', '仉', '督', '子车', '颛孙', '端木', '巫马', '公西', '漆雕', '乐正',
                 '壤驷', '公良', '拓跋', '夹谷', '宰父', '穀梁', '晋', '楚', '闫', '法', '汝', '鄢', '涂', '钦', '段干', '百里', '东郭', '南门',
                 '呼延', '归海', '羊舌', '微生', '岳', '帅', '缑', '亢', '况', '後', '有', '琴', '梁丘', '左丘', '东门', '西门', '商', '牟',
                 '佘', '佴', '伯', '赏', '南宫', '墨', '哈', '谯', '笪', '年', '爱', '阳', '佟', '第五', '言', '福']
    NAME_BODY_MING = ['壮', '昱杰', '开虎', '叶行', '家越', '煜文', '家惟', '龄之', '俊有', '啸威', '浩一', '向红', '军', '建荣', '紫威', '彬', '作为',
                      '博轩', '爵', '榕轩', '韦聿', '仁腾', '诏涣', '勇宁', '东阁', '泰寰', '春军', '翼帆', '诏炀', '培帆', '又淇', '谦韵', '子柏',
                      '永慧', '仲泉', '恒一', '恒源', '凯', '大奇', '兴宁', '笑野', '浩峰', '宪', '伟平', '彦博', '树魏', '坚武', '梓华', '啸吟',
                      '华繁', '啸宇', '健奇', '艺臣', '一同', '疾风', '伟洪', '镜敏', '政浩', '子旭', '玉轩', '子林', '延赤', '禾', '环球', '亚韬',
                      '昊俊', '嘉汶', '纯德', '天宇', '盛世', '华山', '兆临', '泽光', '栗', '樯', '一辉', '闻博', '国洋', '毅杰', '建可', '惠山',
                      '谦之', '连喜', '溪俨', '学江', '树鹏', '鹏', '天友', '庆宇', '本凤', '少涛', '键程', '厚霖', '泽一', '清嵘', '车亦', '新民',
                      '志东', '剑清', '海霖', '一溪', '融渝', '玺剑', '超宇', '永润', '人月', '炳荣', '冰博', '季栋', '仁赫', '兰斌', '嘉伟', '军军',
                      '鄂', '思华', '建青', '兴华', '冀川', '赞平', '佳汛', '万鹏', '飞平', '树隶', '子桁', '志忠', '柯茗', '佛晓', '之帆', '晟尔',
                      '守均', '茁壮', '梁宇', '博洪', '亚军', '翼成', '胜轩', '子皿', '记博', '博玉', '继优', '翰琨', '均培', '敦强', '浩羽', '先登',
                      '明津', '潇添', '燃', '章见', '本三', '仁甫', '小磊', '文福', '鹏云', '成虎', '家正', '来麟', '树木', '超勇', '榀荃', '博涛',
                      '炳越', '宝全', '浩然', '明华', '士琪', '自逊', '风力', '世玉', '文禹', '付增', '戊石', '天麟', '新宇', '彭弘', '玉松', '绍优',
                      '熹伟', '才铭', '以优', '丰', '文丁', '凯菱', '霆', '禹萌', '唯', '建捷', '韦仅', '立安', '星博', '文誉', '洛漾', '丰翌', '心我',
                      '榛元', '承乐', '运晟', '霆锋', '明鉴', '宝愈', '国宇', '维稼', '乐玺', '二', '张钰', '柏晨', '铱', '尊', '晓斌', '益思', '敬敏',
                      '艺怊', '嘉增', '栋良', '棁', '家宇', '思宜', '恩昊', '逸鹤', '雍颐', '光煜', '智怡', '培治', '涛远', '东东', '文舆', '怿',
                      '健民', '如意', '万昆', '腾中', '明德', '铨坤', '招', '道军', '书畅', '万祥', '名川', '雨沛', '英钧', '禹诚', '湘溢', '咏壹',
                      '丁翱', '志虎', '黎烘', '艺言', '照临', '泓敖', '志男', '赫名', '传金', '晖涵', '轩齐', '启宇', '韬淘', '熙恒', '渡', '晓戈',
                      '兆均', '旭九', '能嘉', '佳尧', '天松', '毛瘩', '胜尧', '米黄', '福伦', '林烨', '邦鑫', '奕臣', '会军', '泽江', '云辉', '志皓',
                      '之烨', '焕起', '逸宁', '庆国', '晏霆', '桡铭', '子地', '家辉', '鹏飞', '辉煌', '于瑞', '梓棕', '中彦', '锦尧', '福昌', '辛戎',
                      '寰宇', '家雨', '立刚', '城石', '侦烨', '记政', '威新', '润兵', '天添', '磐石', '礼发', '苏联', '一豪', '义彪', '霄', '再熠',
                      '于皙', '嘉韬', '胜群', '宝同', '一了', '冠毅', '红中', '宇捷', '卿', '政昊', '博文', '培然', '粲粲', '昱天', '一铄', '廷', '丁',
                      '西成', '茂赓', '克帅', '惠达', '世洲', '郁安', '振舫', '三瑞', '哲昱', '源源', '云起', '吉尔', '黎鑫', '鳅锋', '钰满', '致辉',
                      '培海', '立华', '灿昕', '新颜', '子灏', '京辉', '晋尧', '争', '逸舟', '镐', '小峰', '择石', '吾行', '天硕', '宇飞', '钧哲', '睿',
                      '恺越', '锦彦', '子豫', '绅缘', '力飞', '昊坤', '紫昊', '雨凡', '生诩', '黎泓', '方欣', '大帝', '青', '奕融', '博松', '士海',
                      '煜烽', '柏铎', '晋', '誉皓', '献军', '鸿儒', '家维', '晨旭', '发全', '松俊', '厚林', '若帆', '匀浩', '广明', '甫元', '本烽',
                      '水泉', '天赐', '士红', '更航', '汉涛', '纬', '相淇', '渊龙', '近任', '彦钧', '铄', '易磊', '雏腾', '步财', '力帆', '先智', '岩',
                      '畦嵘', '之恒', '霈焱', '文相', '诚之', '临渊', '嘉靖', '昊鑫', '宇辰', '锶齐', '育博', '忠泽', '国文', '绎皓', '晏玮', '丁予',
                      '晖', '大兴', '恒翡', '元八', '学军', '尚印', '立志', '绍友', '献林', '永生', '军旗', '亚', '泳嘉', '云岩', '宏敏', '倍林',
                      '煜濮', '又元', '颢继', '志博', '子晟', '哲骞', '洪贤', '思危', '学斌', '新平', '驰云', '泽峰', '耀明', '竟凯', '天彤', '钰文',
                      '国权', '健深', '家瑜', '大伟', '丞', '前坤', '志洋', '世强', '颖军', '支聿', '栋宇', '子尘', '缘博', '卫', '仁东', '现春',
                      '保建', '丞扬', '禹宣', '嘉恒', '明翰', '昊军', '飞仰', '煊', '弛', '志豪', '世智', '文祥', '嘉骐', '镇', '晓龙', '盛名', '晋嘉',
                      '允', '鸣哲', '思锐', '子宏', '效金', '恪震', '稼', '文程', '树文', '天意', '金勇', '义山', '卫东', '富仪', '国威', '泯柱',
                      '羲峰', '元三', '明章', '玮新', '鼎余', '新立', '旭飞', '冠发', '子钱', '玉峰', '晨硕', '智杰', '跃明', '东森', '薪扬', '俊宝',
                      '宝强', '敬宁', '钰竣', '润', '梓城', '冰溢', '艺洋', '柏言', '一涵', '国维', '学而', '子彧', '晓皓', '增', '杰', '明顼', '渝',
                      '家一', '振中', '阗田', '伟', '钰逵', '晶皓', '泺杰', '晟之', '孟利', '维', '宏康', '兴云', '奭彧', '新昊', '华良', '应腾',
                      '晋坤', '泉景', '益玮', '偌石', '曦恒', '德', '博武', '陆鑫', '耀崎', '志民', '泓轩', '家祺', '勇搏', '莘源', '永进', '子源',
                      '山', '乐轩', '帆', '文斌', '长鑫', '修铭', '罡毅', '火根', '金朱', '熹远', '子鼎', '鸿羽', '鸿峰', '贺迪', '伟明', '引平',
                      '财茂', '深泉', '储剑', '己辉', '振东', '偲齐', '劲杉', '垒', '风宝', '泽众', '宇军', '仲源', '彦乐', '鸿义', '新悦', '哓翕',
                      '旭军', '保真', '会勇', '永红', '建安', '天烘', '金忠', '祎藤', '自鸣', '志超', '立荣', '逸清', '多旭', '大采', '必杰', '承智',
                      '岭楠', '锦伟', '忆罗', '亚辉', '剑锋', '子鹰', '稿', '玮霁', '轶铭', '宏民', '悟石', '奔', '鑫田', '书行', '寒峻', '伟东',
                      '云驰', '新钧', '时立', '润和', '裕', '彦', '子珩', '荐程', '嘉政', '昕源', '畦尧', '祖东', '雨卓', '潍', '志琪', '涵博', '乐平',
                      '浩坤', '厚郴', '俊熙', '进', '新忠', '绍涵', '震天', '哲力', '峻', '明军', '沛帆', '志朋', '无悔', '煜燊', '剑飞', '开宇',
                      '韶荨', '民成', '子岩', '健', '棋西', '程', '云杰', '皓坤', '为民', '耀建', '成伟', '翊程', '宏谟', '叮咚', '泳杰', '儒绅',
                      '锦浩', '柽锘', '达', '子忱', '晓旭', '伯伟', '雄霸', '怀民', '豫', '本祯', '月东', '永菜', '洲', '宁', '霄城', '钰润', '宇佳',
                      '瑞林', '树勋', '永圯', '中芏', '生明', '霄龙', '臻安', '维强', '亦多', '文启', '艺逞', '宗寿', '勇刚', '佳祥', '怀仁', '家祥',
                      '柯言', '若熙', '立东', '付华', '光宇', '文靖', '康', '熹玮', '联博', '志勇', '子千', '泽辉', '雍仪', '新源', '忱', '彦文',
                      '裕淼', '阳阳', '一鸣', '天琪', '晓垒', '国庆', '建华', '搏涵', '越羲', '子辰', '瀚为', '峻逸', '昀天', '全心', '铭浩', '云',
                      '浩成', '建明', '新文', '闻涛', '中进', '印螺', '思胤', '子才', '哲栋', '小霄', '永利', '子宣', '抱石', '平宁', '依贻', '永兴',
                      '华彬', '匡胤', '焕军', '会初', '文俨', '银全', '禹然', '付荣', '小龙', '泉盛', '黎弘', '文行', '煜恒', '力玮', '清满', '怀荣',
                      '永波', '炳珲', '光雷', '建珂', '江立', '记策', '佳洲', '英策', '旭君', '韦迪', '子欣', '贤文', '鹏远', '子丞', '梓希', '霖',
                      '泽生', '永淇', '文铧', '广勇', '呈', '力苇', '颢', '晓生', '大国', '绍教', '焙', '渝川', '尧', '厚相', '崇', '偲煜', '恩',
                      '扬', '致墚', '桐瑞', '宜帆', '辉华', '易恒', '盟潞', '刘一', '诚诚', '欣煜', '子骐', '学海', '烙豪', '子震', '智友', '智永',
                      '志鸣', '小文', '李杰', '艺什', '均伟', '宝良', '俊男', '选军', '文振', '禹森', '靖玮', '哲轩', '健程', '毅轩', '守君', '子良',
                      '寅', '柏泽', '之琰', '子竞', '言', '绍珺', '鑫哲', '亚鹏', '海根', '树楷', '榄', '义杨', '佳腾', '晨帅', '奕宁', '岩松', '艺明',
                      '悦阳', '名', '本安', '雨晨', '吾稷', '诣修', '子信', '广修', '禹函', '方方', '新新', '天舒', '鹏智', '议麦', '子峰', '品桦',
                      '致', '钰昆', '智敏', '碧宝', '子安', '卞聿', '子腾', '黎宏', '民琦', '安琪', '国旭', '西俊', '志乔', '元一', '瑞俊', '隆',
                      '良枝', '源荣', '东', '丰文', '厚彬', '厚楚', '儒祥', '铁军', '天玄', '津川', '国辉', '子弘', '宏海', '嘉贤', '恒欣', '纯烨',
                      '晓涛', '建国', '嘉诚', '斌宇', '鸿潍', '懿良', '路', '勃', '永锋', '钊', '毅瑞', '树岗', '卓羲', '子太', '聿珂', '林峰', '煜铠',
                      '传昌', '旷元', '子恩', '焱年', '妙丰', '俊皓', '泽元', '连仲', '跖', '孙侃', '靖', '为正', '子钦', '傲立', '元五', '锷', '东明',
                      '诩', '大圣', '烁贻', '煜熙', '译文', '占环', '梓言', '西雷', '长凇', '志玮', '临旭', '延波', '竞博', '沩', '庆威', '元聿',
                      '琦逸', '宏韦', '俊峻', '可东', '宝玉', '烨之', '烨明', '鹏博', '亦尘', '泽之', '子琛', '之涣', '砚', '天鹏', '思谐', '浩震',
                      '学宁', '戈雷', '思愚', '子亮', '启', '贵有', '嘉牧', '有科', '沛淮', '礼义', '轶文', '铄海', '宇钦', '俊彦', '焯楷', '森东',
                      '文起', '琪逸', '玉忠', '波', '闵柱', '锐柏', '鸿敏', '旌任', '贝宠', '继龙', '子熙', '天田', '秋廷', '凯瑞', '首钧', '书瀚',
                      '钽轶', '立新', '志文', '华君', '综融', '湘汝', '恒宽', '平峡', '轩海', '书玉', '屹玮', '常明', '昊', '雨童', '福胜', '鲑埔',
                      '佳明', '丁元', '迄', '文志', '红兵', '志威', '宪军', '庆军', '凡玄', '桂超', '明红', '如昕', '玄峰', '惟', '北北', '新雨', '巍',
                      '保刚', '鼎天', '国正', '步高', '鑫源', '淼淼', '太阳', '叶宣', '本艇', '财明', '贝聿', '煜钢', '君平', '方成', '秦', '心砚',
                      '安勇', '醇烨', '誉怀', '得亮', '广嘉', '立宏', '紫腾', '炬', '联锋', '占波', '劲', '梓洋', '文俊', '霈然', '毅剀', '海宾',
                      '洪君', '顺娃', '国沧', '大大', '树立', '腾辉', '语宇', '务石', '钰坤', '剑柯', '志锁', '普加', '亚伟', '彬杰', '荐成', '相龙',
                      '诗泽', '晨洋', '玉胜', '崇岳', '鼎民', '兴疆', '嘉福', '玮珀', '飞帅', '士杰', '笑山', '盟坷', '官全', '星昊', '天依', '同安',
                      '天俞', '均炜', '启越', '子赫', '彦淮', '允禄', '翰宇', '遭', '本亮', '乙征', '三奔', '燮林', '经程', '天骥', '值浩', '滔',
                      '万海', '宇晨', '寒骏', '师心', '小凯', '飞麟', '中锴', '凯聆', '金铢', '勤', '利军', '昌盛', '庆', '建志', '龠曦', '宇', '朕',
                      '长鸣', '淳烨', '桂鸣', '育栋', '小', '嘉喜', '延龙', '韦稼', '岩郊', '心念', '文廷', '梓俨', '鹏宇', '建谨', '灿', '宇恒',
                      '颐轩', '为为', '栀荣', '梓烨', '礽宠', '鼓腾', '涵一', '传艮', '伟新', '锶铭', '坤澎', '宽巧', '富强', '新路', '鳅渔', '舒同',
                      '天问', '心宝', '彦恺', '晋中', '勤元', '继之', '梓成', '全', '昭炀', '言郊', '清栋', '吉平', '开石', '华臣', '博虎', '学汉',
                      '仁', '海波', '鹤', '铭桐', '永屹', '轩鸣', '泓扬', '铭学', '博宇', '进兴', '德军', '禹暄', '田', '家宝', '晋帷', '成梓', '宏潍',
                      '友碧', '景博', '大琦', '清荣', '雪中', '万里', '钦', '一庭', '溯溯', '大勇', '承', '化忠', '京津', '鑫磊', '加乐', '培玉',
                      '启策', '正刚', '柯涵', '辛昊', '安各', '志会', '钊恒', '令锋', '烁', '全昆', '成科', '天国', '树威', '鲁愚', '伯虎', '诩生',
                      '文哲', '赢文', '崇楦', '铁成', '金波', '文海', '梓平', '旭敏', '铎海', '顺利', '鸿维', '润军', '铭轶', '洪川', '灼', '金城',
                      '才恒', '鼎弘', '孚融', '东博', '文林', '梯烨', '旺旺', '焱宁', '衍昀', '义芝', '神', '泸', '国荣', '康宁', '世伟', '家连',
                      '跃建', '建平', '渝淇', '科州', '凌博', '立明', '柽铭', '乐瑞', '恒铭', '记昀', '速捷', '宏维', '涵文', '吾光', '云轩', '俊入',
                      '义', '锁川', '寄平', '丁曦', '国明', '文栋', '纪苏', '成昊', '广玉', '四昱', '光强', '晨扬', '奕炜', '一晗', '金梁', '明勇',
                      '钰澄', '飞', '伟鹰', '李谊', '晓翰', '浚', '世平', '爱国', '安铃', '雪酉', '大峰', '鸣世', '文霖', '德志', '竟胜', '泺漾',
                      '伟铭', '欣汝', '玉斌', '钟海', '崤龙', '思言', '育恒', '慧来', '亚峰', '墨然', '烁桐', '爱民', '浩智', '桂柱', '张晨', '赫明',
                      '立群', '程枫', '皞晖', '怀东', '珉柱', '烜', '献武', '瑞华', '禧贤', '子育', '皓文', '博林', '红涛', '源太', '绍军', '野', '璨',
                      '金迟', '悦边', '伟力', '羽其', '昭', '文双', '书兵', '广同', '宏儒', '书航', '开华', '恒德', '会光', '延岭', '元七', '贺僮',
                      '博思', '友恒', '士铭', '赫铭', '子鉴', '子天', '郝宇', '天榆', '昊泽', '旺牛', '思博', '国全', '洪勋', '南星', '纪超', '一闻',
                      '剑峰', '赢', '子鹏', '海澎', '振胜', '厚哲', '恒薪', '时予', '黄米', '良缘', '树彪', '冠玉', '振宜', '野夫', '占华', '楚一',
                      '瑜涛', '茗辉', '仁秋', '福山', '文青', '宝国', '道能', '晓明', '云贵', '嘉尧', '宝贤', '友仅', '添锦', '曦', '钧崴', '永杰',
                      '稳锋', '与彦', '治铭', '宏卫', '彦民', '逸飞', '云天', '仁会', '沛之', '吾航', '茗柱', '问谨', '学潼', '旭彤', '炳超', '少江',
                      '子狄', '浩雄', '冰剀', '应彬', '树伟', '天福', '雨辰', '挺', '广', '懿轩', '岭南', '毅', '建成', '效忠', '瑞', '吉根', '盛利',
                      '世泽', '仪宇', '浩权', '璞煜', '艺桥', '常鸣', '伟林', '锌轩', '齐恺', '其明', '玉文', '思洗', '亚斌', '泰钧', '亚伦', '宗羲',
                      '锃', '铭钐', '皓元', '戟', '一宁', '彬洲', '子翔', '朝府', '佛霆', '无极', '用颐', '建龙', '志强', '子晨', '见波', '鹏珂',
                      '全琨', '胤燃', '高雅', '跃', '蛟蛟', '煜轶', '学奇', '胤贤', '柏慧', '传奇', '泽云', '永熠', '恺稷', '祖寿', '海涛', '敏沣',
                      '泽林', '稽', '杰成', '天鸿', '宣辰', '涛', '文骐', '建飞', '战平', '文滔', '熙宇', '汉翀', '浩骅', '浩晟', '华桥', '建基',
                      '本初', '天昀', '杰俊', '杨又', '凯怡', '鸿艺', '屹森', '琭珧', '晨晖', '淏轩', '旭阳', '荣荣', '鸿基', '雨杰', '振铭', '忠雷',
                      '天玉', '河征', '则石', '振明', '东梁', '小才', '玺宇', '志为', '德胜', '树廷', '子清', '佳程', '辛宇', '宇欣', '银发', '有祥',
                      '文府', '学峰', '建深', '栗源', '科淇', '宇帅', '夕优', '台', '心均', '家荣', '本强', '孟勇', '天烁', '建方', '国敏', '子封',
                      '嘉生', '艳强', '尔丰', '荃坤', '晏瑞', '今朱', '荣德', '埔铖', '子聪', '文敬', '子琦', '光辉', '白卓', '子宬', '耀哲', '财华',
                      '庆友', '聪宇', '朝蓬', '宁仁', '荣达', '子桀', '烁哲', '安戈', '无克', '锐哲', '旺', '晓珲', '征', '树辉', '祚誉', '海洲', '诏',
                      '辰若', '熔石', '政', '易贻', '君卓', '晨煜', '海彬', '天爱', '林鹏', '力', '晨罡', '力邦', '龙泽', '成振', '世升', '名琛',
                      '克豪', '洛嘉', '梓源', '元九', '启丞', '天齐', '勒', '新会', '林霄', '新刚', '松康', '昱升', '楚煊', '福宣', '家伟', '雨龙',
                      '皓', '晟铭', '艺巩', '锫帆', '永辉', '明浩', '拓', '崇俊', '可欣', '邵敏', '荣华', '燕鹏', '可光', '信崴', '逸吉', '明刚',
                      '寓原', '晓凡', '泉宇', '久彬', '欣圣', '科晴', '殿红', '煜铭', '一廷', '洛', '文力', '睿扬', '水欣', '广军', '占龙', '水莘',
                      '剑', '鸣', '余荣', '圆源', '善宏', '连华', '紫豪', '彦锦', '祥刚', '讯谟', '屿', '球', '桓铭', '云州', '奕卿', '淇尔', '建博',
                      '淋', '述平', '文玄', '新国', '灵博', '思凡', '厚湘', '冰汝', '晨阳', '元二', '惠宣', '九龄', '雷', '泉', '杉', '悦鑫', '墨晗',
                      '紫翰', '爱新', '天龙', '力铭', '梓研', '钊华', '沛晟', '禹轩', '竞锐', '若石', '宜程', '沛天', '添', '瀚文', '胜', '思渐',
                      '常入', '超', '民柱', '瑞希', '天辉', '成刚', '浩斌', '与', '筌贰', '仕海', '林宾', '诗育', '思彦', '添易', '济恺', '人之',
                      '帅奕', '思恒', '健生', '弘韬', '如', '铁平', '嘉正', '文富', '鼎凯', '均', '思谚', '健凯', '梁东', '呈炜', '义琛', '超越',
                      '竟轩', '强', '海云', '赞', '晨祺', '雨晟', '治华', '斯祁', '文熙', '浩嘉', '英浩', '鑫仪', '耀匀', '紊文', '清漾', '崇源',
                      '政喃', '飞扬', '山川', '允潇', '鞠国', '春杰', '文余', '邦峰', '如稷', '信孜', '文昕', '李承', '邻溪', '宇轩', '佳林', '赵勇',
                      '鼎愚', '怀友', '崴', '成彪', '士立', '江宇', '凯彦', '贵元', '县科', '兆轩', '轶震', '元十', '永兵', '毅怊', '子烨', '胜玉',
                      '金华', '甲辉', '欣源', '子昕', '益波', '广垒', '荣', '钏海', '清淞', '礼维', '为政', '国超', '云奇', '胤诚', '紫瀚', '春天',
                      '弘力', '丁天', '小丁', '小皓', '苠柱', '清哲', '淘淘', '伟伟', '子雷', '海亮', '祺法', '文澜', '泰', '利帆', '仅开', '若盛',
                      '成程', '彪石', '尉一', '迦乐', '雨鑫', '振学', '博寒', '山山', '思镐', '佳乐', '立民', '飞雄', '江龙', '铭峰', '彬哲', '福荣',
                      '彦祺', '铭', '希林', '乾坤', '越恒', '德录', '元乃', '同举', '岩石', '泽华', '金', '硕恒', '承文', '正', '德智', '天合', '春铭',
                      '新录', '筹', '震舫', '紫炜', '瑞涛', '焉平', '一征', '本焱', '天阳', '闵闵', '景智', '德耿', '长荣', '金塔', '兴月', '敬云',
                      '洪杰', '铮海', '琪亮', '凤岐', '天洪', '子豪', '释予', '师禹', '继耐', '捷', '家成', '小伟', '向华', '建永', '绰鉴', '兴俊',
                      '洪涛', '蔚波', '火霄', '正阳', '开吉', '木椟', '大增', '必胜', '大宇', '艺胜', '泰力', '诚', '海琛', '韶齐', '雪健', '潇凯',
                      '畔', '焱森', '力川', '杰城', '豫暄', '子贵', '弘维', '元四', '玉杰', '之初', '淮南', '禹权', '智海', '又辉', '增沂', '涵宇',
                      '达生', '泽川', '灿灿', '保红', '嘉境', '翔', '喜顺', '小瑞', '思尧', '哲文', '聪欣', '增荣', '仁杰', '杰晟', '柳稳', '顺敏',
                      '富平', '勃松', '旌宇', '凌棱', '众', '雍', '兴雨', '日广', '林溪', '富城', '杨广', '一彤', '永亮', '武飞', '利宝', '恒铨',
                      '中民', '笑铭', '珑译', '耀希', '侦驰', '车羽', '哲', '胤然', '煜玺', '源', '弈儒', '糟', '椿烨', '通震', '轩祐', '旭星', '小华',
                      '泓维', '瑞杰', '东海', '力弘', '思波', '林玉', '国石', '云哲', '尚轶', '学勤', '舒民', '林', '红东', '煜权', '人稼', '祺恺',
                      '竞', '凯明', '柽铎', '瀚宇', '文晋', '守禄', '衍', '韦众', '志宏', '啸龙', '梏', '昶然', '东琛', '文良', '瀚引', '品谋', '玮炜',
                      '水源', '天羽', '智渊', '成云', '天红', '贺淇', '志刚', '家墨', '起林', '金石', '毫晨', '释之', '叙淳', '海', '子扬', '则玉',
                      '栗琛', '建杰', '鸿志', '凌晟', '晔', '柏', '纤昊', '勃滨', '克平', '禄', '要攀', '诏震', '皓寓', '孜洋', '世杰', '了一', '宸豪',
                      '子亲', '威皓', '炫锋', '露中', '建人', '达宁', '泽岐', '贤先', '建洪', '玉富', '晓峰', '海冰', '恪铭', '钰麟', '奎胜', '梓立',
                      '煜盛', '曲坤', '子昱', '浩润', '嘉轩', '家豪', '本航', '本田', '宇凡', '羽粲', '天佑', '士硕', '昕宇', '洪源', '健树', '特',
                      '子伯', '厚汀', '蛟', '宏', '浩伟', '涌太', '天琦', '华冰', '胤言', '春明', '江', '云祥', '翌轩', '政皓', '震坤', '春龙', '超刚',
                      '刘畅', '振', '科理', '占久', '财将', '高', '近冬', '官', '凯翎', '斯旗', '友林', '润恒', '尉', '腾', '羲', '清洋', '智俊',
                      '子凡', '迦勒', '贺彤', '轶华', '俊星', '焕', '瑞熙', '维杰', '晋伟', '雨亭', '振宇', '志儒', '隆吉', '嘉乐', '锐', '小东',
                      '自川', '濂敏', '李轩', '共金', '永贤', '靖百', '腾达', '田烽', '鼎儒', '种', '学山', '卫华', '友清', '亚涛', '明雨', '唯德',
                      '仅众', '联全', '友烨', '富华', '献', '峻艺', '祥洲', '紫石', '楷铭', '长亦', '雪山', '张黄', '天', '余晗', '忠世', '志诚',
                      '文超', '继承', '炳文', '鸿灏', '一诺', '春皓', '胜文', '鹏举', '丞含', '政权', '举纲', '靖嘉', '文庭', '献文', '言骄', '承民',
                      '崇懿', '享眠', '邯', '明涛', '琥诚', '首军', '瀚', '孟达', '新澳', '李诚', '韦臣', '曾刚', '宜宣', '家鸣', '越', '祁强', '宏宇',
                      '维东', '凡雨', '宇通', '杨航', '谦昊', '海中', '维新', '怀亮', '竞胜', '晟烨', '叶良', '存吉', '畦山', '名柱', '一峰', '熙',
                      '佳伟', '立杉', '景波', '凯仪', '隽', '航滔', '大海', '文睿', '汝杰', '天祥', '仕杰', '峰铭', '思渠', '志昕', '午光', '思渤',
                      '泽滟', '芪', '永俊', '一水', '雪飞', '洧', '拙羽', '兵', '河江', '长征', '海岩', '之荣', '牧', '飞羽', '子涵', '卫新', '丁文',
                      '文涵', '咏辉', '基栋', '翎西', '奂奂', '星宸', '柽名', '冲', '梓伟', '呈珉', '壹冰', '炜鹰', '尔泰', '龙文', '吉松', '荪',
                      '殊言', '帅克', '闯', '军伟', '传君', '一钰', '德银', '宇栋', '占平', '加琛', '子亚', '叶航', '卓雨', '凇', '子渊', '轩豪',
                      '宪君', '纬新', '珑', '梁栋', '益坚', '晓东', '巴聿', '世恩', '延年', '智泽', '玉一', '元旦', '凯昕', '若钢', '黎俊', '傲伟',
                      '韶奇', '之栋', '皕', '涣晟', '硕楠', '蛸龙', '益甫', '爱军', '祥雨', '泽霆', '嘉锡', '凯杰', '利安', '正飞', '雪涛', '煜汀',
                      '华', '武盾', '圣群', '硕', '雨桐', '莘田', '其', '楚宁', '文博', '泊泽', '研博', '官钱', '洪敏', '政哲', '德俊', '广森', '岳灿',
                      '青洋', '矛', '前进', '建席', '国生', '隽巍', '世缘', '秉彰', '林佳', '玉祥', '臻', '逸卿', '红力', '艺众', '泳淇', '齐', '明宇',
                      '子伟', '兆启', '恒轶', '李博', '筱林', '繇', '怡浩', '庆平', '亨太', '海培', '相茗', '啸', '侦仲', '莜昊', '笠仲', '梓严',
                      '宇琨', '佳坤', '元瑞', '维龙', '永康', '钝海', '铎馨', '书铭', '朝洋', '为一', '厚杳', '振波', '鑫铭', '德利', '安', '辰宇',
                      '瑜生', '心源', '宝', '竹林', '智墚', '森栋', '凯晨', '国飞', '忠洁', '建宁', '明星', '天宝', '臣', '新禄', '若焕', '策钧',
                      '辛生', '子健', '艺皓', '清伟', '字逊', '成龙', '宇乐', '车聿', '昀程', '晋文', '号号', '桂成', '俊', '青松', '文明', '思禹',
                      '飞雨', '炯', '椿雨', '文兵', '奇', '成', '庭境', '隆石', '用', '凡子', '恒', '镇雄', '阔', '伟佳', '宜靖', '行', '颢冰',
                      '绍赓', '若辰', '天洋', '兴利', '禹芪', '建艺', '闻宇', '子灵', '泽皓', '福胤', '雪吉', '博伦', '天瑜', '兴贤', '泽瑜', '耀辉',
                      '缙尧', '永泉', '一羲', '谢书', '天宁', '焕平', '阵', '伍一', '嘉誊', '子孜', '帅权', '继忠', '硕颀', '嘉林', '业龙', '明泽',
                      '江红', '少勇', '钰哲', '肇明', '培天', '聪灿', '煜田', '畅鑫', '思维', '远理', '迅崭', '嘉畦', '璞', '安之', '永以', '晟恺',
                      '淇', '名渊', '泽鑫', '乐', '文宝', '振鹏', '政豪', '德勤', '昌正', '贵云', '立虎', '骅', '术祥', '滨勃', '佛廷', '凌波', '福宝',
                      '乐杉', '友田', '子栩', '帷', '若刚', '国钧', '浩南', '风', '旺财', '嘉锐', '君入', '彪', '耀新', '崇巍', '禹阳', '定星', '笑添',
                      '立双', '赞品', '连科', '文浩', '奕晨', '岷柱', '章钰', '辰维', '骁纹', '嘉庚', '小兵', '统元', '泽俊', '志杰', '洪伟', '庆喜',
                      '悦洋', '文新', '林熙', '志欣', '文瑜', '卜亓', '宝黎', '椿宇', '禹', '麒森', '御言', '春宇', '贺任', '梁', '鹏义', '怀曦',
                      '志缘', '学桐', '胜利', '振宁', '智博', '子枫', '丰岚', '小攀', '七七', '建荩', '威廉', '啸博', '明', '勇阳', '钧威', '海文',
                      '昱珂', '树棋', '增才', '家宏', '健声', '本升', '君麟', '文亮', '锡康', '岩平', '攀锋', '昱承', '禹诺', '记福', '凌林', '明成',
                      '韵锡', '田丰', '亦溪', '元哩', '建郁', '峥旭', '渭', '满意', '红博', '圳', '斯文', '汝杉', '麒淞', '安军', '文楠', '怀宁',
                      '海双', '夔闼', '奋仁', '俊安', '智稼', '宏建', '恒通', '利国', '弈舟', '禹芩', '普华', '利', '伟杰', '抚山', '珈铭', '品幕',
                      '振林', '宏炜', '一童', '羽拙', '柏林', '旭岩', '久翔', '恩石', '熠桐', '昊东', '凯华', '思进', '骜', '银海', '槿铭', '祥俊',
                      '明松', '梓杭', '小康', '翊暄', '欣宇', '凡卜', '爱铭', '中宝', '诚程', '佐英', '重庆', '记顺', '子琪', '武', '子谦', '杰然',
                      '吉伟', '天白', '义磊', '惟新', '双川', '了', '玉强', '凯信', '永斌', '方洲', '长发', '可人', '天弘', '炫锐', '富明', '俊枫']

    NAME_GIRL_MING = ['小玉', '蓝', '琬郡', '琛青', '予舴', '妙妙', '焱诺', '艺歆', '芮熙', '悦优', '艺杨', '艺惠', '爱芬', '含因', '楚菊', '佳禾',
                      '婧妗', '玉容', '文莉', '娅雯', '碧连', '芊菲', '宇娜', '志妍', '天馨', '静', '涵雅', '辰语', '瀚樱', '小捧', '丹丹', '黎腩',
                      '丹华', '文璐', '芳辉', '浚丽', '才霞', '采嫦', '梦琪', '泥', '映月', '铱芳', '馨馨', '媛鑫', '紫萱', '玉春', '韶玥', '紫玉',
                      '丽静', '藤娟', '朵', '贞', '佼悦', '珍宝', '千叶', '嘉琪', '丙芳', '玉琴', '丽雅', '影祺', '潇琳', '寒凝', '赛', '竹梅', '颜婷',
                      '靓颖', '亦菲', '颖萌', '筵彤', '岚羽', '茜柔', '钦玥', '伊茗', '嘉韵', '花玲', '蕤', '子歌', '佛瑶', '云丽', '彩杰', '稼妮',
                      '华蓉', '彦芳', '笑', '尹真', '笑榕', '语潼', '雪虹', '婧雯', '玉菡', '欣妍', '佳丽', '盈乐', '思佳', '卜鸾', '建婷', '桐菲',
                      '岑', '雅彦', '婧颖', '氏艳', '舒畅', '谦雅', '馨文', '帼玮', '子鲜', '惠君', '成艳', '言婷', '美琪', '轺骊', '诗青', '慧英',
                      '凤霞', '琼也', '贝', '湘玉', '鑫卉', '巧兰', '姝英', '惜颖', '珈', '靖茹', '予易', '艺涟', '冰竺', '兰锁', '菁鹤', '理微', '瑛',
                      '盼望', '楚含', '雯舜', '歆翌', '迪欣', '菡韵', '桂芳', '贵英', '艺榕', '跹', '键蓉', '歆迪', '草', '爱素', '丽景', '春笑',
                      '慧娟', '玉佳', '密密', '译诺', '雯煜', '雪晴', '骊莉', '贝瑶', '文琼', '淑莲', '子娇', '珍瑜', '水芯', '晨芳', '岚爱', '琳艳',
                      '冬萍', '成梅', '冬梅', '茜茹', '恬语', '恬', '睬嫦', '珂芯', '旖旎', '金芝', '紫凝', '希颖', '淑仙', '亚萍', '佳钰', '雪冰',
                      '兆珍', '冰涵', '静飞', '昱瑶', '启玲', '韵', '英英', '露瑶', '含裴', '屏', '梅娥', '亚卿', '橼丹', '琬琪', '华梅', '三红',
                      '灿荧', '佳颖', '纯杉', '春雨', '碧雪', '悦兮', '雅星', '甜甜', '惠珺', '润梅', '雪琴', '梦迪', '莺罂', '钰荣', '悦颜', '若琪',
                      '静如', '可露', '雅晴', '淑杰', '雨柔', '紫佟', '青桐', '淑志', '白茹', '伟玲', '肖竹', '佩君', '羽桐', '玉凤', '宗艳', '艺萍',
                      '爱佳', '志玲', '雪萍', '筱玲', '华兰', '玉馨', '孜萱', '伶黎', '雁溪', '松燕', '润琳', '晓蜜', '立英', '巧灵', '真希', '梦凡',
                      '欣奕', '婷', '网娣', '月露', '妮娟', '沁雯', '岚瑛', '悦辰', '静妍', '籽铃', '淑雅', '小白', '翠萍', '紫桐', '索菲', '盈盈',
                      '巍璇', '欣雨', '思苏', '美珍', '若芸', '思蓓', '婷菲', '娅', '纯菁', '昀琪', '恩蕊', '梓媛', '晓君', '闵琼', '语珊', '亟奕',
                      '姣平', '施', '彩芬', '桂荣', '广琴', '蒙笑', '晓萍', '恋泯', '枫栏', '紫晴', '德霞', '雪晶', '翊含', '紫楦', '苓君', '兆凤',
                      '文警', '馨瑶', '紫瑛', '叶雯', '温馨', '婉晴', '爱华', '书琳', '梓萱', '思冉', '艺潼', '兰芬', '卉彤', '美鑫', '玉兰', '馨逸',
                      '伊诺', '潇佳', '静莎', '秋凤', '倩楠', '奕瑶', '培娟', '玉霜', '千菲', '理薇', '晨鹭', '淑景', '碧莲', '宝芳', '雅婕', '淑敏',
                      '卫芳', '予晗', '潇霄', '丽婧', '铁娟', '茜榆', '晓霞', '月嫦', '妍熙', '春娥', '心艳', '嫘迩', '智娟', '羚淯', '芷洁', '怡嘉',
                      '雪芹', '伶藜', '黛媛', '左婕', '心羽', '蕴蔷', '倩可', '晶淋', '茵桐', '悦淇', '桂榕', '琇赑', '姝玉', '珞彤', '心瑶', '禹晴',
                      '怡然', '杰兰', '美祎', '晓琳', '灵宵', '子怡', '雅烨', '迦兰', '黛妤', '曾弈', '嘉玲', '宇蔓', '英兰', '文珏', '籽萱', '仁艳',
                      '蔓茗', '盈馨', '吴瑾', '露予', '英博', '紫嫱', '樱', '馨怡', '艺苔', '海珍', '瑾晶', '莹爱', '奕晴', '航旖', '馨贤', '亚冰',
                      '贞如', '兰同', '苡露', '昕玉', '之菁', '梅珠', '雅玲', '惠梅', '嘉雯', '溪茹', '金绣', '翊倩', '思竹', '译予', '邦蓉', '为艳',
                      '甜冶', '语菲', '湘孜', '樱琼', '诗妤', '钰桐', '玲梦', '曼珂', '玥熹', '思姚', '韫金', '鹛邡', '蓉蓉', '茵芝', '芝君', '娇宁',
                      '玺露', '肖冰', '琼', '敏捷', '家媛', '少虹', '轶芳', '珏媚', '朝娣', '晓雨', '菲箐', '若诗', '惠娴', '艺越', '伶利', '姝雅',
                      '荠蔚', '婧宇', '洁莹', '梅玲', '婷恣', '雅莉', '紫贤', '思蕊', '星月', '开梅', '籍丹', '筵栖', '思冰', '稼婷', '琴', '邦婕',
                      '婧菡', '琪雨', '瑞琪', '黎楠', '易含', '翠雅', '馨妍', '滢滢', '一枚', '正英', '淑贞', '邦雯', '佃芳', '茜颖', '田妮', '铃',
                      '瑞凤', '艳洁', '琬悦', '骊元', '霈雨', '加姿', '海晶', '栩园', '紫欣', '立静', '雯絮', '苏菲', '梓钥', '晏佳', '茉然', '锦鸽',
                      '羽晴', '悦茜', '元圆', '渔雪', '俊琴', '思霞', '利花', '雨朦', '栩圆', '玲芬', '兰军', '留霞', '若嘉', '睛', '弈盈', '邦莎',
                      '钰荥', '珏欢', '沂蓉', '瑛琪', '婉', '冬琦', '寒微', '畦芎', '如怡', '思斯', '朱琴', '绽雪', '文琴', '欣', '新雅', '剑萍',
                      '蔓泽', '新慧', '琳翊', '籽妙', '君蕊', '诗雨', '韵琳', '青春', '芳', '亚欣', '盼兮', '晓钰', '思琰', '巧稚', '芸', '缠曦',
                      '丁丹', '蕾镭', '艳霞', '小雨', '东玲', '讳隽', '瑜茜', '美荣', '六梅', '婕宇', '沁彤', '风青', '欣桐', '美媛', '树燕', '昱芊',
                      '彩霞', '岚昀', '紫雯', '小羽', '灵儿', '芬芬', '烨涵', '雨楠', '宵蕙', '维香', '映荷', '毓萱', '艺囝', '艳娇', '筵蕊', '雨菡',
                      '新菊', '王菲', '静男', '雪岩', '斯诺', '向娟', '子璇', '语墨', '颐雯', '珂欣', '辰颖', '静玉', '沁范', '海艳', '晓洁', '煜萍',
                      '甜茜', '珺莉', '姝雯', '伊瑶', '婧璇', '翊茹', '可涵', '萩薇', '梓妙', '瑞菊', '依彤', '巧', '妤芊', '玟琳', '夏月', '润眉',
                      '影', '正美', '娅琳', '靖菲', '喻露', '馨茹', '心如', '颖桦', '珊妹', '悦然', '黎娜', '盈羽', '晋玥', '漫霓', '渫晴', '滢茔',
                      '浣西', '欣羽', '真茜', '紫梓', '一媛', '程茵', '宇馨', '梦玲', '娅冰', '逸舒', '文萍', '斯琴', '景红', '清梅', '月英', '翕颖',
                      '翠英', '梓丽', '冰蕊', '楚函', '绚海', '晓雪', '彦茹', '慧慧', '馨辰', '楚依', '婉合', '占莉', '立琴', '亚莉', '荧', '蒙萌',
                      '蔓辰', '婷曦', '玲平', '子琼', '倩怡', '当当', '雯耀', '雯佳', '鹳央', '雅淇', '凤茹', '沁帆', '若嫣', '梓伊', '琫晖', '茄霖',
                      '钰淼', '湘匀', '菁胭', '虹', '运蓉', '囡囡', '保玲', '淑璇', '若思', '佳榕', '卓茜', '晓瑞', '聪洁', '婉仪', '筵朋', '珏悦',
                      '潇颖', '湉蕊', '静江', '玉莹', '韵菡', '茵彤', '舒彤', '可盈', '秀丽', '伶俐', '慧郡', '静柔', '若羽', '冰茜', '旭姻', '淑',
                      '舆敏', '译月', '桂卿', '冰芳', '邦丽', '舒雅', '沁菲', '玥', '馨予', '容琨', '娇娇', '令菲', '伶', '宝英', '迎婷', '英坤',
                      '懿珈', '靖晴', '萍华', '安霞', '才梅', '艺含', '梦杰', '美月', '远芳', '诗雅', '宁娟', '静芳', '曾伊', '唤清', '洽恰', '屿彤',
                      '诗毓', '宇璐', '海媚', '昱丹', '晓菁', '露壬', '田甜', '盼希', '王丽', '桂芬', '诺焱', '蔓菱', '璇玥', '桂洋', '巧芸', '紫韩',
                      '真儿', '素君', '静怡', '心悦', '歆月', '乐薇', '予馨', '茔茔', '婉萍', '予涵', '奕涵', '思昀', '静伟', '小阅', '璐桢', '靖悦',
                      '雨诺', '小雯', '晓燕', '梦娜', '微茹', '奕凤', '琇', '金涵', '艳敏', '含汶', '迎瑕', '亦雯', '清妍', '紫', '铃铃', '欣甜',
                      '肇娟', '乙黛', '运丽', '嘉伊', '翊筠', '欣欣', '向静', '静琰', '玥淼', '新萍', '梦兰', '智晴', '俊婷', '艳诚', '荔', '虹烨',
                      '雪境', '家兰', '蜜蜜', '冬英', '桂娇', '千艳', '荟君', '洁宁', '慕白', '荟筠', '建珍', '謦', '洪侠', '雨婕', '妍', '茗蕊', '尹',
                      '春柳', '丽蓉', '力香', '祎甜', '小燕', '冰瑶', '美美', '世娟', '雨珂', '雨蒙', '馨媛', '娃娃', '杰婷', '佳瑜', '巧韵', '香菏',
                      '斐禾', '梓茜', '雅馨', '晓曦', '智雅', '格筵', '慧仪', '景梅', '海英', '佳琪', '付燕', '馨笛', '紫奕', '思菁', '彩画', '沅梦',
                      '纳文', '书韵', '箬晗', '妃妃', '洁', '昀萱', '雅文', '笑宁', '丁丽', '弈雯', '婉钧', '小思', '育娜', '晓萁', '春菲', '惜源',
                      '玉雪', '楚洁', '一玫', '铄滢', '雪颖', '聪丽', '鑫雅', '美秀', '茗寒', '心心', '忆如', '梓萌', '妁', '雪媛', '琳鑫', '娟鹏',
                      '子媛', '文瑛', '潇涵', '婵', '丽岚', '美茜', '静琳', '怡欢', '威茹', '笑函', '真萍', '苗亦', '丹', '岑茵', '聆可', '梅香',
                      '筵冬', '珈影', '彩文', '海雯', '艳飞', '曦颖', '应琴', '偌菡', '俊芳', '彦颇', '祈蓝', '彦妍', '金露', '立玲', '县丽', '培芳',
                      '采薇', '倩倩', '玲华', '英', '海红', '珺娴', '怡雯', '改玲', '艺童', '燕婷', '孟雪', '海珠', '心迪', '洪丽', '于影', '昕予',
                      '以琳', '瑞婕', '姝月', '黍洁', '薰今', '东曼', '雨琪', '语佟', '林露', '燕萍', '唯玮', '淑茗', '惠华', '鸿燕', '雯辉', '金莲',
                      '乙靓', '桂红', '雅静', '娜瑛', '妍嘉', '乃琚', '丽淑', '静嫣', '语心', '沁', '家姿', '爱宁', '梦海', '彩芳', '纤亦', '栏',
                      '凤珍', '淖翔', '红梅', '雪儿', '春红', '兰颖', '军霞', '姿', '雯予', '莉芬', '嘉玉', '玉英', '艳焱', '雅琪', '巧瑛', '蒽诺',
                      '临芳', '秀利', '凤焉', '贻茜', '玮环', '香涵', '米', '洳洳', '玉', '洁鑫', '玉童', '静菡', '语', '芷晴', '惠圆', '欣如', '珺',
                      '烨菲', '茜', '延婷', '婧琦', '熠绮', '颖', '径盈', '舒然', '书悦', '丹熠', '珂馨', '义琴', '思沫', '一晴', '又丹', '歆桐',
                      '斯研', '纳', '苏颖', '韵雅', '靖雯', '惠颖', '璐祺', '惠郡', '心歌', '雅真', '喜兰', '竹莎', '予敏', '烟雨', '荔荔', '涵凝',
                      '琬迪', '如思', '晓艺', '娜祺', '季语', '珈乐', '潇湉', '俊婕', '尤玥', '玉涵', '俊娴', '美玉', '妤亭', '红琴', '葭', '艾琪',
                      '莺', '智瑶', '萧尹', '丽丽', '曾泓', '依涵', '冰凝', '梅英', '雅儒', '妍溪', '新颖', '丽荣', '楠钰', '丹其', '筱蒙', '雪焦',
                      '馨雨', '姝瑛', '湘雨', '凯妍', '盼溪', '贵梅', '巧婵', '巧宁', '馥瑞', '业蓉', '丹凤', '茵程', '如忆', '海娟', '珏朋', '丽达',
                      '胜菊', '岱雯', '紫聪', '菲凡', '昭容', '姝涵', '昱苹', '一惠', '豆叮', '彩云', '若岚', '丹琦', '琳青', '思', '莺桦', '芬',
                      '漫呢', '云娜', '楚君', '炳娟', '英雪', '妤熙', '俪潆', '雪彤', '婧焱', '韵非', '雅利', '芷瑜', '利芳', '菲晴', '星语', '昕颖',
                      '新熳', '煜玲', '岩婷', '黎荭', '湉心', '珍珠', '美萍', '彦秀', '钰涓', '满红', '良妍', '颖菲', '雅漩', '研婷', '偌遥', '贤芝',
                      '霓', '斯雯', '雪恬', '淑芹', '一萌', '佳恬', '俪婷', '顺琼', '漫旎', '潇雅', '猗', '优优', '黍娴', '细霞', '琇淼', '翠花',
                      '黛一', '淑贵', '美华', '于咏', '爱枝', '伶郦', '紫佳', '紫慧', '茗', '艺楚', '艺扉', '琳慧', '含玥', '晓薇', '思燕', '馨元',
                      '晴雯', '季秋', '莉娜', '湘君', '智仙', '若丝', '巾谰', '疏桐', '春梅', '钥', '兰峰', '雪琦', '菲蕾', '欣静', '美红', '姬',
                      '占翠', '知琳', '筱筱', '翊岚', '红岩', '竞予', '小花', '漫', '力鳗', '蒙雪', '云慧', '英菲', '瑗', '占艳', '红雨', '思语',
                      '思瑜', '剑芳', '云闲', '艳花', '文婕', '欢欢', '熠菲', '夕娴', '浚莉', '钰萤', '姚伶', '叶瑶', '婉琳', '容韪', '紫菡', '黛源',
                      '筵芮', '璎萌', '函翊', '妞', '静蓉', '亚男', '楚苹', '满雪', '怀蓉', '逸萌', '煜葶', '风瑜', '黛怡', '珍珍', '彩峡', '安婷',
                      '苡柔', '晶馨', '琀骊', '榆婷', '静琨', '蓝月', '盈淼', '真', '淑雨', '雨欣', '俪予', '紫琀', '亚朋', '小瑗', '紫瑞', '玉蓉',
                      '茗萱', '帆菲', '素琴', '蒂', '瑞芝', '春晴', '旭莺', '语彤', '瑾', '嘉潼', '哩哩', '娉婷', '贤雅', '颖颖', '延霞', '茜婷',
                      '小叶', '小萌', '丽', '陈嫦', '丹蕊', '曾熠', '琦瑶', '从侠', '海侠', '珏琪', '茗栾', '海妹', '梦童', '梓潼', '子菲', '馨茉',
                      '又分', '秋娴', '鹭', '琫', '翠奉', '偌瑶', '书芳', '珈嘉', '晨伊', '欣怡', '玉滢', '朋筵', '苡菲', '译男', '茵瞳', '小莹',
                      '春慧', '欣瑶', '蓦瑶', '熙雯', '语洋', '玉慧', '桂莲', '黎英', '曾逸', '惠榕', '嘉姿', '填艳', '秋锦', '尤艳', '方艳', '女馨',
                      '逸芳', '梓舒', '国兰', '雨婷', '茹', '益兰', '梦洁', '虹蕾', '菲帆', '笑涵', '岚颖', '彤梦', '艺萌', '婧妤', '红月', '洁贞',
                      '春懿', '芯', '讳郡', '晓淇', '玫莹', '芹霞', '春婷', '金珠', '均瑶', '雪竹', '晓霜', '泽璇', '丹红', '伶莉', '若缺', '丽慧',
                      '铭淑', '慧丽', '保芳', '译易', '佳缘', '柔婷', '思伽', '久娣', '业丽', '丹艺', '钰茹', '沁浛', '旃婴', '楠', '静烟', '心慈',
                      '采清', '作娟', '晓欢', '淑宇', '婧宏', '婧琰', '盼好', '子娴', '蔓宸', '雯鼎', '莲生', '思羽', '智馨', '圣玲', '丝媛', '菁璠',
                      '晓晶', '萌笑', '蕊', '黎男', '云艳', '欣语', '玉露', '媛媛', '雪倩', '莉霞', '芯伶', '筵晰', '煜莹', '筱奕', '露瑾', '文蕊',
                      '蓝分', '甜也', '楚潼', '子琀', '缘朋', '二媛', '微晞', '佳晏', '诗颖', '辰菲', '焱嫦', '藜静', '舒', '凤娇', '琨晶', '菊芹',
                      '梦欣', '冬菊', '絮哲', '媛曳', '幸红', '心昕', '桂云', '榕蕴', '佳茵', '盼盼', '韵斐', '诗瑜', '含', '芹', '净妃', '静静',
                      '矜钥', '嘉钥', '雨萌', '思恬', '蔓瑶', '莹姝', '乃慧', '月晗', '海韵', '悦恬', '彩', '淑英', '语麦', '欣艾', '雅姿', '艳婷',
                      '金娣', '婷婷', '月恬', '曾谊', '洪梅', '建娥', '占美', '冰月', '丽霞', '倩茹', '洁霖', '闲云', '黎赧', '恋', '漪妃', '芷蕾',
                      '琬昱', '媛苑', '碧丹', '靖琪', '含音', '子雯', '荟乐', '湉仪', '佳羽', '艺珺', '苓翊', '巧荣', '晓琴', '文韫', '茹译', '舒译',
                      '松琴', '乃芸', '瑾璞', '樱淇', '琪悦', '恒美', '思桠', '凤荣', '滢舒', '秀荣', '栗梅', '姗娜', '亦珊', '慕贞', '秀乡', '小凤',
                      '碧月', '黍沁', '潇燕', '静雯', '米淇', '盈曦', '乔楠', '学蓉', '纯雯', '璞玥', '黛月', '冰淼', '惠丽', '雨含', '玉涓', '爱菊',
                      '奕雯', '艺霏', '嵛爱', '雨晴', '蕙郡', '梦晗', '祎恬', '苛茜', '珏变', '晓莉', '彦涵', '絮琪', '华英', '霓芝', '双双', '英迪',
                      '灵', '明香', '新芬', '善美', '乐园', '琬琬', '玉秋', '丁莉', '月菱', '娅书', '芳茜', '黛熙', '琰莹', '爱云', '玉芳', '世慧',
                      '紫璐', '黎红', '妙玲', '招英', '笑怡', '瑞玉', '滢淼', '画', '靓', '聪敏', '毓婷', '倩如', '蕴', '晓楠', '雨寒', '春英', '义珍',
                      '雪琳', '婧媛', '冰晴', '梦伊', '耐花', '亚隽', '倩雅', '秋梅', '诗兰', '子蕊', '凤芝', '雯怡', '菲烨', '艳荣', '雅丽', '昕心',
                      '亚茹', '霁倩', '梓玥', '卉郡', '婧菲', '辰玥', '漪楠', '淑霞', '馨月', '海霞', '丽瑾', '湉馨', '娟芳', '孓乜', '悦涵', '怀瑶',
                      '栩瑶', '佳琳', '容欢', '玉璠', '宝凤', '靖萱', '菲菲', '敏嘉', '小朋', '雅君', '巧悦', '琬敏', '鹃', '婧彤', '榕珈', '绮绮',
                      '璠', '语晗', '楚蓠', '羽菲', '奕丹', '宝蓓', '欣竞', '橼香', '溢溶', '巧洁', '翘', '小薇', '皎月', '黍涓', '汉娜', '洪霞',
                      '溢蓉', '彩桦', '玲菱', '璀蝉', '杰媛', '圆圆', '毓琪', '楚萍', '翠翠', '筵溪', '玉静', '霞斌', '含婴', '佐洁', '芮儒', '辛怡',
                      '晓雯', '艺竞', '菁涵', '清雪', '宇琼', '思桐', '占香', '慧华', '子晶', '瑞梅', '荑', '卜露', '虹苏', '丹梓', '文侠', '格畅',
                      '妮颖', '思怡', '琼仙', '潞涵', '雨娜', '艺融', '之倩', '蕴蓥', '蒙欣', '露婵', '嘉怡', '籽柔', '恬悦', '译心', '宝玲', '玫',
                      '静胭', '思飘', '颖哲', '芷萌', '莜苒', '翊妍', '月云', '雯杰', '佳珂', '惠芳', '婉菁', '玉情', '智岚', '修兰', '娅娜', '巧英',
                      '茂玲', '欣蕊', '茵僮', '金兰', '雅雅', '春丽', '育梅', '惠玲', '钰清', '唯依', '悦琴', '玉冰', '芯悦', '美', '若雪', '天英',
                      '开艳', '子婴', '一瑗', '梦佳', '雯叙', '芯蕊', '永霞', '鑫蕾', '馨静', '真艺', '娉', '学艳', '鑫莹', '云菊', '静菲', '婷文',
                      '格', '秋', '彦妮', '韶婕', '惠黎', '容', '艺涵', '应梅', '欣然', '冰雪', '凤斐', '露凝', '溪媛', '蕾蕾', '梦桃', '朦月', '容轩',
                      '苡馨', '有琴', '静贤', '芝瑗', '雾瑕', '艺潞', '依雯', '妤炯', '心彤', '素敏', '净', '晗琪', '乔荟', '心爱', '樱萱', '芯玙',
                      '俊菊', '培珍', '玲英', '小双', '靖虹', '梓函', '容伊', '邦薇', '靖晗', '墨涵', '冰蝉', '艺晗', '素芹', '钰淇', '莉红', '惠媛',
                      '芷莹', '彩嫦', '潇', '芷真', '二翠', '春月', '艳芬', '沁湘', '梦涵', '晓兰', '蕴潇', '兰谊', '译君', '紫云', '欣玥', '旭瑛',
                      '秀粉', '冰柠', '翎', '慧梅', '静轩', '安妮', '晓春', '一萍', '萸艳', '恚捃', '筱竟', '淑平', '佳昕', '又芬', '立娜', '秀容',
                      '枘雨', '庆秀', '春燕', '苏瑶', '筵颉', '芷源', '可莹', '绘郡', '黛宁', '中艳', '俏寒', '亚秋', '雪平', '梦茹', '俪曦', '钰妃',
                      '慧贞', '巧利', '净桐', '世霞', '荟郡', '昱霏', '韵奕', '忻瑶', '溪蕾', '艾萍', '嘉歆', '艳辉', '乙晶', '秀', '语昕', '琳琳',
                      '邦莉', '孟妍', '一珺', '孝菊', '涧晴', '与芊', '爱萍', '依笑', '美婷', '美娟', '菁妍', '丽洁', '昭瑗', '贤翠', '雪蓉', '珂茜',
                      '沁韵', '晶琨', '丽丰', '婼宝', '炜婷', '月煜', '薪欣', '丽珊', '笳卉', '玉瑛', '纯微', '仪雨', '肖红', '惠芬', '利娟', '真花',
                      '威洁', '妮妮', '琳力', '蕾明', '艳艳', '诗语', '楚凤', '圆', '芷姗', '歆', '晶欣', '贤珺', '伟芬', '心盈', '双涵', '梓艺',
                      '笑昀', '芳敏', '晓倩', '桂宁', '国梅', '译匀', '欣悦', '韵寒', '铁萍', '邝邑', '涵悦', '采霞', '书媛', '晏彤', '紫菲', '云砾',
                      '鑫蕙', '梦亭', '秋凝', '一男', '煦晴', '化英', '邦妹', '寒素', '莹琨', '岚', '紫暄', '林芳', '淑琴', '巧玲', '彦敏', '胜娟',
                      '新艳', '馨丹', '改娣', '梓莹', '雅倩', '丽威', '丽市', '云琦', '峻莉', '梓盈', '馨宇', '思寒', '清莉', '晓园', '敬茹', '玲玲',
                      '采妮', '雪菡', '小慈', '聪妮', '蔓莹', '小芳', '小娟', '馨方', '先媛', '雨诗', '春姝', '诗怡', '婕', '凤丹', '伶妗', '玥玥',
                      '珺骊', '冰俏', '水莲', '文霞', '利娜', '师娴', '梨梨', '筵郗', '娣', '静焱', '姝婷', '羲颖', '筵格', '郦', '英杰', '迎雪',
                      '丝嘉', '媛琪', '丽欣', '灵琴', '雪会', '寒莹', '媚莹', '薇', '芝榕', '晓慧', '斯语', '雁冰', '青敏', '莎莎', '秀慧', '倩云',
                      '荣珠', '惠璞', '晗涵', '英睿', '舒馨', '平芝', '真瑜', '丽惠', '苓菱', '雅琦', '钰洁', '黎喃', '办艳', '育红', '海燕', '弈茹',
                      '筵曦', '予婕', '湄姗', '一卉', '仪凡', '嫦茜', '佳湘', '紫薇', '慧宇', '云芳', '芸菁', '小珊', '雅秋', '俏明', '紫帆', '淑芬',
                      '薇文', '晓涵', '昭雪', '溶依', '丽华', '芮曦', '竞男', '叶', '淑烨', '舒沁', '琳茜', '佳', '娉娉', '群媚', '晓云', '津樱',
                      '桐俏', '蕴茴', '心兰', '立萍', '缠糯', '瑗琪', '艾娜', '润妍', '云霞', '语童', '秋香', '蓓', '颜', '月琪', '彦婕', '境薇',
                      '秀瑛', '凤贵', '雨霏', '悦含', '颖佳', '彤彤', '飒', '嘉薇', '丹扬', '兴茹', '中花', '一菲', '唯伊', '锦芝', '佳咨', '乙潞',
                      '筱宇', '潇蔷', '秋花', '宇萱', '思晨', '一萱', '金瑶', '紫莹', '芝华', '伟娟', '珏文', '佐婕', '玉儿', '津芝', '璧儿', '斓菲',
                      '飘', '笑萱', '玉翠', '颖乙', '敏焰', '金枝', '苗潇', '鑫媛', '朵菡', '雪蕊', '艳', '美雯', '永兰', '庆玲', '聪娅', '籽烨',
                      '恭兰', '家珍', '仪涵', '常秀', '文娟', '玄睫', '焕莉', '漫妮', '子萱', '冬青', '薇茹', '了尹', '敬莎', '路语', '潇缤', '晗彤',
                      '竞丹', '婧文', '甜语', '曾翊', '嘉琳', '昭茜', '若兰', '祺玥', '婧', '汝雯', '彦瑾', '丽鑫', '婷玉', '以柔', '旭缨', '佳姊',
                      '语燕', '秀美', '紫寒', '泺滢', '莛', '小丽', '丽菲', '若涵', '馨田', '奕洁', '雅雯', '秀云', '云舒', '筠', '娈', '婉杉', '沁涵',
                      '琳佳', '沁雅', '思晗', '莺宁', '旭晶', '尹倩', '庭凤', '菁琰', '芷蔓', '彦芹', '秋月', '晓漫', '馨仪', '韶韵', '苏钰', '忆琛',
                      '盼曦', '嫣', '业莹', '晓侠', '子莉', '姬月', '佳梓', '曼婷', '焕婷', '靓妍', '远萍', '依霖', '薇茜', '丽珠', '黛毓', '晨思',
                      '国艳', '君玉', '芮', '菁菡', '骊骊', '兮艳', '书沁', '邰璇', '如艺', '怡甜', '丹璐', '乙彤', '晗悦', '漫雪', '尘香', '芷涵',
                      '讳筠', '宁忆', '蕴萦', '雪', '英华', '东丽', '景芳', '寒怡', '琳', '思楠', '湘佳', '菲雪', '韵舒', '誉玲', '冰露', '芸萌',
                      '雨舒', '婧帆', '水馨', '雪娇', '思予', '雅芙', '淑华', '浚俐', '增彩', '栖蕴', '玺凤', '藤容', '元芳', '景月', '双男', '笑雯',
                      '珏灵', '雨烟', '小琴', '索霏', '湘语', '誉艳', '箐', '雯跃', '润芳', '爱芝', '珏婷', '芮萱', '楚涵', '雪拽', '紫璇', '奕妍',
                      '煜婷', '可悦', '彦莲', '朵朵', '苏苏', '琴燕', '智燕', '娟花', '贝贝', '敬玲', '鹤丹', '丹奇', '馨卉', '思仪', '学玲', '靖芝',
                      '诗涵', '苡葶', '英芳', '妍姿', '馨伊', '琰婷', '雨雯', '昭媛', '雁茹', '华妮', '舒文', '萍玲', '羽亭', '溪铃', '俊霞', '月心',
                      '莹', '兰子', '嘉薪', '建仙', '阅涵', '钰芳', '昕怡', '蔓宇', '芷槿', '海聆', '子婵', '旎', '亚玲', '秋六', '萌烨', '文娇',
                      '瑞兰', '克娥', '乙涵', '丹冰', '海丽', '梓含', '义芳', '片艳', '菁蕊', '春霞', '玲娟', '菁嫣', '栖含', '佁函', '笛笛', '思暮',
                      '桂香', '季月', '乙露', '惠惠', '雯琳', '椿燕', '凤仙', '思侠', '爱桐', '湘梦', '煜莺', '敬怡', '文静', '绣玲', '爱媛', '歆洁',
                      '玉淇', '筱彦', '雅苹', '苏诺', '煊婷', '邦倩', '怡芮', '佳芮', '宝琴', '斐然', '绮晗', '媛', '旭瑶', '乙伊', '谦影', '楠楠',
                      '荔莉', '语瞳', '小语', '之侠', '书莲', '姿萱', '妤伊', '金花', '莲珍', '羽潼', '予绮', '若晴', '莲泯', '紫沐', '诗琴', '崴茹',
                      '伊涵', '心怡', '乐怡', '菀莹', '佛兰', '僖玉', '蕴涵', '语桐', '曾宜', '瑞巧', '惠丹', '慧', '艺琼', '清红', '昱惠', '芮菡',
                      '克娟', '溪潺', '书瑶', '沁凡', '舒晨', '星慧', '倩菲', '美玲', '姣姣', '艾珂', '彦静', '玉芝', '惠', '亚君', '翠华', '凯媛',
                      '芮希', '笑卿', '紫玥', '宁茜', '蒴', '婕媛', '婧宁', '嗉凤', '守芬', '雪昕', '秀琴', '红云', '翊函', '星燕', '月淼', '紫耘',
                      '佼', '晓娟', '琬童', '英舜', '鹤馨', '钰滢', '琬', '佳沐', '燕妮', '晓珊', '秀杰', '惠琳', '英春', '馨忆', '婕杏', '贤凤',
                      '妍卿', '素云', '筠鸿', '春茜', '庆霞', '馥琳', '一莉', '红果', '喏璐', '泓曾', '运珍', '伶丽', '海含', '碧悦', '婕羽', '羽洁',
                      '浛', '秀芹', '佳心', '凤艳', '静姝', '爱卿', '诗韵', '巧云', '悦婷', '佳旋', '田娅', '颖鑫', '幸溶', '欢', '世琴', '燕玲',
                      '邦梅', '如兰', '苡荣', '凤麟', '灿蓓', '骊', '弦月', '雪凡', '亚琛', '晓佳', '雯一', '弈莹', '竹连', '静虹', '葑', '睿馥', '敏',
                      '秋虹', '莎', '晓红', '艳波', '梦珍', '寒冰', '秀娥', '斯妍', '绮鑫', '军花', '珊', '冬莲', '窈嫒', '世美', '银珠', '欣湉',
                      '彭媛', '欣霏', '菁焰', '玲鑫', '如诗', '绍莲', '菲梵', '若音', '江丽', '文秀', '美琳', '茜宝', '佳孜', '利英', '左洁', '艳平',
                      '文婷', '玉鹃', '琪琪', '影萍', '艺雯', '月蘅', '寒笛', '冰禅', '雯华', '静岩', '建英', '小瑶', '淑慧', '栉烨', '佳姿', '颖巍',
                      '彦萌', '淑征', '偌晗', '语湘', '什艳', '宏丽', '斯羽', '禹菡', '琨静', '璇海', '于娴', '韵沁', '晓琪', '萌昀', '黍婵', '金荟',
                      '志茹', '晶婧', '秀彦', '允琳', '容容', '黎虹', '琪蔚', '筱淇', '慧扬', '建秀', '玲丽', '琳颉', '思悦', '琨莹', '巍娟', '碧桃',
                      '菡悦', '鑫洁', '露露', '文菊', '彤屿', '锦月', '纨', '桂芝', '舒帆', '慧蓉', '素萍', '秀茹', '恬妞', '新月', '才茹', '一霏',
                      '书琴', '婧懿', '茹春', '玥心', '淑存', '雅慈', '一靓', '璇', '雯淇', '桠菽', '赛琦', '琰萍', '光雯', '小慧', '大珍', '婧暄',
                      '月晶', '含颖', '妍熹', '旭慧', '梓喃', '秋莲', '潇莹', '荟冰', '筠莉', '昆丽', '丽婷', '雅湘', '锦芳', '俊英', '小筱', '内艳',
                      '雯露', '心菁', '紫涵', '茜如', '誉娟', '娴', '馨如', '籽昱', '若晗', '云媛', '瑶蓓', '聪雅', '歆童', '又砾', '碧君', '亚春',
                      '童漩', '纤男', '雯岚', '源梦', '萌乐', '俊菲', '小霞', '炎婷', '晰晴', '新英', '梓茵', '海蓉', '语娜', '馨琦', '晓馥', '佳翊']

    def random_int_str(self, count: int, first_zero: bool = False):
        """
        生成指定长度的随机数据字符串
        :param count: 长度
        :param first_zero: 生成的数字字符串 首位是否可以为零
        :return: 字符串数字
        """
        if first_zero:
            return self.__random_base(count, self.NUMBER)
        else:
            while True:
                value = self.__random_base(count, self.NUMBER)
                if str(value[0]) != '0':
                    return value

    def random_lower_str(self, count: int):
        """
        生成指定长度的随机小写字母字符串
        :param count: 长度
        :return:
        """
        return self.__random_base(count, self.LOWER)

    def random_upper_str(self, count: int):
        """
        生成指定长度的随机大写字母字符串
        :param count: 长度
        :return:
        """
        return self.__random_base(count, self.UPPER)

    def random_low_upp_str(self, count: int):
        """
        生成指定长度的随机字母（大、小写）字符串
        :param count: 长度
        :return:
        """
        return self.__random_base(count, self.LOWER_UPPER)

    def random_low_upp_number_str(self, count: int):
        """
        生成指定长度的随机字符（大小写字母+数字）
        :param count: 长度
        :return:
        """
        return self.__random_base(count, self.NUMBER_LOWER_UPPER)

    def random_low_number_str(self, count: int):
        """
        生成指定长度的随机字符（小写字母+数字）
        :param count: 长度
        :return:
        """
        return self.__random_base(count, self.NUMBER_LOWER)

    def random_upp_number_str(self, count: int):
        """
        生成指定长度的随机字符（大写字母+数字）
        :param count: 长度
        :return:
        """
        return self.__random_base(count, self.NUMBER_UPPER)

    def random_name_str(self, gender, is_two_xing=False):
        """
        生成随机姓名
        :param gender: 性别（男、女）
        :param is_two_xing: 姓是否是2个字的（默认是1一个字的姓）
        """
        # step1 生成姓
        xing = ''
        if is_two_xing:
            while True:
                xing_two = self.NAME_XING[random.randint(0, len(self.NAME_XING) - 1)]
                if len(xing_two) == 2:
                    xing = xing_two
                    break
        else:
            while True:
                xing_one = self.NAME_XING[random.randint(0, len(self.NAME_XING) - 1)]
                if len(xing_one) == 1:
                    xing = xing_one
                    break

        # step2 生成名
        ming = ''
        if gender == '男':
            ming = self.NAME_BODY_MING[random.randint(0, len(self.NAME_BODY_MING) - 1)]
        elif gender == '女':
            ming = self.NAME_GIRL_MING[random.randint(0, len(self.NAME_GIRL_MING) - 1)]
        else:
            print('性别错误')

        return xing + ming

    @staticmethod
    def random_ip():
        """
        随机IP地址
        :return:
        """
        ip = '{}.{}.{}.{}'.format(
            random.randint(1, 223),
            random.randint(0, 255),
            random.randint(0, 255),
            random.randint(0, 255)
        )
        return ip

    @staticmethod
    def __random_base(count: int, type):
        value = ''
        for c in range(count):
            value += str(type[random.randint(0, len(type) - 1)])
        return value


if __name__ == '__main__':
    jar_random = PyUtilRandom()
    print(jar_random.random_low_upp_number_str(15))
    print('136' + jar_random.random_int_str(8))
    print('136' + jar_random.random_int_str(8))
    print('136' + jar_random.random_int_str(8))
    print('\r\n\n\n\n\n\n\n')
    print(jar_random.random_int_str(19))
    print(jar_random.random_int_str(19))
    print(jar_random.random_int_str(19))
    print(jar_random.random_int_str(19))
    print(jar_random.random_int_str(19))
    print(jar_random.random_int_str(19))
    print('\r\n\n\n\n\n\n\n')
    print('0x' + jar_random.random_low_number_str(40))
    print('0x' + jar_random.random_low_number_str(40))
    print('0x' + jar_random.random_low_number_str(40))
    print('0x' + jar_random.random_low_number_str(40))
    print(jar_random.random_low_number_str(10))
    print('\r\n\n\n\n\n\n\n')
    print('随机手机号：136' + jar_random.random_int_str(6) + '00')
    print('随机手机号：136' + jar_random.random_int_str(8))
    print('银行卡：' + jar_random.random_int_str(19))
    print('银行卡：' + jar_random.random_int_str(8))
    print('虚拟币账户：0x' + jar_random.random_low_number_str(40))
    print('数字：', jar_random.random_int_str(8))
    print('小写：', jar_random.random_lower_str(100))
    print('大写：', jar_random.random_upper_str(100))
    print('小写+大写：', jar_random.random_low_upp_str(100))
    print('小写+大写+数字：', "test" + jar_random.random_low_upp_number_str(3) + '001')
    print('小写+数字：', jar_random.random_low_number_str(11))
    print('大写+数字：', jar_random.random_upp_number_str(100))
    print('随机IP地址：', jar_random.random_ip())

    print(jar_random.random_name_str('男'))
    print(jar_random.random_name_str('女'))
    print('dasd'[1])

    str1 = '赵婧文,赵冬梅,赵璇海,赵绚海,赵玉,赵宵蕙,赵雾瑕,赵俊英,赵敏,赵鹃,赵玉凤,赵容,赵萸艳,赵慧,赵艳,赵德霞,赵玉芝,赵妍,赵江丽,赵伶俐,赵唯伊,赵慧丽,赵紫佳,赵雪凡,赵丽荣,赵稼婷,赵琳琳,赵白茹,赵甜也,赵文秀,赵芳,赵墨涵,赵秋凤,赵玉容,赵甜冶,赵薇,赵倩云,赵春燕,赵静,赵俊霞,赵梓含,赵若岚,赵若兰,赵俊芳,赵文婷,赵子怡,赵英博,赵珈影,赵丽,赵琳,赵海珠,赵淑英,赵笳卉,赵婉琳,赵婉钧,赵乙靓,赵一靓,赵静静,赵雪,赵嘉雯,赵欢,赵玉春,赵一萍,赵晓慧,赵露露,赵翠华,赵兰军,赵媛媛,赵亚秋,赵雅秋,赵婕媛,赵小莹,赵珈嘉,赵英雪,赵静琨,赵晶琨,赵容琨,赵琨晶,赵琨静,赵琨莹,赵莹琨,赵艳辉,赵晓薇,赵小薇,赵诗涵,赵海妹,赵雪彤,赵海含,赵思晨,赵春梅,赵艳波,赵紫帆,赵晓蜜,赵海燕,赵晓红,赵影,赵航旖,赵云琦,赵小叶,赵婵,赵铁娟,赵冰竺,赵钰荣,赵竞男,赵水莲,赵易含,赵心迪,赵翊含,赵翊岚,赵依霖,赵玥熹,赵翊妍,赵婧妗,赵书琴,赵彦颇,赵剑萍,赵楚萍,赵楚苹,赵楚凤,赵楚菊,赵秀杰,赵海红,赵蕊,赵慧梅,赵蕾蕾,赵丽婷,赵婷,赵含,赵茜婷,赵容容,赵丽雅,赵曼婷,赵毓婷,赵美婷,赵以琳,赵羚淯,赵子娴,赵锦芝,赵莲生,赵葭,赵珈,赵艾娜,赵海媚,赵语晗,赵晗琪,赵晗彤,赵语彤,赵浛,赵丹,赵含玥,赵雅琪,赵梓莹,赵芷莹,赵欣悦,赵玥心,赵芷姗,赵心心,赵甜茜,赵彦涵,赵月心,赵心昕,赵怡然,赵昕心,赵乙黛,赵娅雯,赵芷真,赵芷蔓,赵凯媛,赵蔓莹,赵莜苒,赵茜茹,赵智馨,赵茜如,赵真儿,赵智岚,赵智晴,赵淑琴,赵亚欣,赵倩如,赵倩茹,赵雅馨,赵茜榆,赵茜柔,赵偌遥,赵梦海,赵偌瑶,赵雅淇,赵娣,赵雅彦,赵雅烨,赵怀蓉,赵佳沐,赵佳翊,赵梓舒,赵彩霞,赵雅真,赵巧兰,赵开梅,赵国梅,赵毓萱,赵芷萌,赵芝瑗,赵稼妮,赵丽蓉,赵津樱,赵樱,赵英华,赵英迪,赵晓雪,赵聆可,赵爱素,赵丽华,赵芮,赵佳姿,赵紫莹,赵慕贞,赵海韵,赵楚君,赵梓盈,赵紫欣,赵紫晴,赵佳咨,赵佳孜,赵紫慧,赵庆霞,赵思寒,赵佳梓,赵佳姊,赵欣桐,赵嘉姿,赵茵桐,赵家姿,赵加姿,赵倩可,赵茵彤,赵籽昱,赵茵瞳,赵茵僮,赵付燕,赵怡雯,赵迎瑕,赵雯怡,赵亦雯,赵艺雯,赵颐雯,赵弈雯,赵奕雯,赵笑雯,赵晓雯,赵雨雯,赵丽菲,赵淑,赵冰禅,赵春菲,赵思羽,赵璀蝉,赵怡芮,赵冰蝉,赵桂云,赵奕瑶,赵王菲,赵俊菲,赵冰茜,赵沁,赵冰淼,赵倩雅,赵楚涵,赵雅倩,赵冰涵,赵思琰,赵亚朋,赵雅玲,赵潞涵,赵沁涵,赵莺,赵邝邑,赵煊婷,赵湘语,赵冰雪,赵湘玉,赵思暮,赵语湘,赵蕴,赵路语,赵湘雨,赵沁湘,赵金珠,赵黎楠,赵秋六,赵芮儒,赵黎腩,赵黎男,赵辰颖,赵黎赧,赵黎喃,赵铁萍,赵黎红,赵黎虹,赵业丽,赵黎荭,赵鑫雅,赵佳琪,赵静玉,赵悦含,赵美华,赵露婵,赵小花,赵彦茹,赵运蓉,赵迪欣,赵盈馨,赵学蓉,赵玉涵,赵雪蓉,赵乐薇,赵绽雪,赵文萍,赵盈乐,赵涵雅,赵悦辰,赵珺,赵菁蕊,赵伊茗,赵伊涵,赵依涵,赵雪儿,赵秀茹,赵悦颜,赵欣妍,赵漫雪,赵晶欣,赵颖巍,赵满雪,赵雪萍,赵雨晴,赵婧璇,赵洪侠,赵叶,赵雪晴,赵采薇,赵云慧,赵芷洁,赵立萍,赵悦涵,赵兰谊,赵亚隽,赵容韪,赵芯,赵语瞳,赵予敏,赵静男,赵双男,赵译男,赵纤男,赵思冉,赵静琳,赵溪潺,赵晓燕,赵小燕,赵洁霖,赵丽瑾,赵美,赵春姝,赵胜菊,赵心慈,赵维香,赵真艺,赵逸萌,赵小阅,赵栩园,赵栩圆,赵芳茜,赵虹,赵梦茹,赵碧君,赵运丽,赵一枚,赵婧彤,赵静江,赵莲珍,赵珏文,赵永霞,赵盼盼,赵彦瑾,赵婧媛,赵华蓉,赵滢滢,赵丹琦,赵岑,赵芷源,赵玉琴,赵梓茜,赵素敏,赵栩瑶,赵芷槿,赵晓萍,赵霞斌,赵春慧,赵晓洁,赵文侠,赵氏艳,赵艳平,赵灵宵,赵娉,赵娉娉,赵思竹,赵凤焉,赵凤艳,赵怡嘉,赵雪倩,赵兮艳,赵尤艳,赵彩,赵紫,赵月煜,赵田妮,赵竹莎,赵田娅,赵玄睫,赵淑茗,赵婕宇,赵婕羽,赵秋娴,赵片艳,赵悦婷,赵为艳,赵黛媛,赵田甜,赵秋凝,赵昭媛,赵方艳,赵昭瑗,赵心艳,赵开艳,赵填艳,赵云艳,赵妍嘉,赵中艳,赵艺惠,赵桂娇,赵仁艳,赵冰凝,赵什艳,赵占艳,赵办艳,赵内艳,赵茂玲,赵思菁,赵诗琴,赵露凝,赵玲芬,赵雪颖,赵婧暄,赵彦静,赵培娟,赵昕玉,赵栏,赵枫栏,赵欣甜,赵欣湉,赵艺晗,赵艺含,赵兰同,赵元圆,赵圆圆,赵雅君,赵亚君,赵聪丽,赵尹,赵洽恰,赵颖鑫,赵六梅,赵金绣,赵心菁,赵夕娴,赵巾谰,赵姣平,赵千艳,赵清梅,赵芯伶,赵唯玮,赵玫,赵芯玙,赵容欢,赵索菲,赵苏菲,赵索霏,赵丹扬,赵慧扬,赵茜,赵妍卿,赵佃芳,赵冰露,赵渔雪,赵佳禾,赵焕莉,赵小白,赵雪岩,赵奕晴,赵瑾璞,赵秋,赵佳琳,赵千叶,赵莹姝,赵珍珠,赵于咏,赵瑞婕,赵忆如,赵玉冰,赵安妮,赵丽珠,赵雅利,赵雅丽,赵风瑜,赵婕杏,赵静贤,赵琴燕,赵于影,赵于娴,赵悦恬,赵莛,赵丹璐,赵美秀,赵珏欢,赵珏变,赵素琴,赵珏灵,赵珏朋,赵云娜,赵珏媚,赵珏悦,赵寒笛,赵寒莹,赵文莉,赵艺越,赵寒怡,赵丽丽,赵静蓉,赵寒素,赵寒凝,赵恬悦,赵涵悦,赵菡悦,赵晗悦,赵翘,赵玉霜,赵建秀,赵跹,赵莺宁,赵晨伊,赵俪婷,赵燕玲,赵琪琪,赵辰语,赵碧丹,赵晓瑞,赵玉儿,赵如兰,赵兴茹,赵姣姣,赵娇娇,赵娅书,赵菲菲,赵优优,赵笛笛,赵铃铃,赵竹梅,赵若晗,赵竹连,赵欣瑶,赵梓妙,赵泽璇,赵梓函,赵妙妙,赵梓钥,赵珍珍,赵清莉,赵囡囡,赵楠楠,赵蜜蜜,赵妮妮,赵洳洳,赵韵舒,赵潇佳,赵黛月,赵晓佳,赵玉雪,赵玉情,赵慧慧,赵亚卿,赵正英,赵彩画,赵彩桦,赵翠萍,赵美娟,赵玲丽,赵嘉钥,赵贤珺,赵舒然,赵皎月,赵仪凡,赵兰子,赵立娜,赵婉合,赵莉娜,赵甜甜,赵芮希,赵亟奕,赵师娴,赵笑萱,赵悦琴,赵晓园,赵淑贞,赵晓君,赵珂欣,赵有琴,赵秀琴,赵秀芹,赵娅娜,赵秀瑛,赵丽丰,赵苓君,赵佳缘,赵钰清,赵珂芯,赵修兰,赵钰滢,赵钰芳,赵贤凤,赵凤芝,赵燕萍,赵翠英,赵爱芬,赵美萍,赵艳霞,赵旎,赵玥玥,赵艺霏,赵银珠,赵桂芳,赵蔓菱,赵翠花,赵肖竹,赵春晴,赵俏明,赵艺潞,赵舒晨,赵锦芳,赵景芳,赵安婷,赵英春,赵梦珍,赵东玲,赵思语,赵惠芳,赵冬青,赵甜语,赵宝英,赵贞如,赵诗语,赵一莉,赵晓云,赵晓兰,赵紫云,赵冬英,赵梦玲,赵佳榕,赵志茹,赵宝凤,赵一霏,赵聪洁,赵向娟,赵晋玥,赵玉翠,赵志玲,赵培芳,赵小慈,赵玺凤,赵雅慈,赵从侠,赵妍溪,赵艳焱,赵妍熙,赵语燕,赵斯研,赵斯妍,赵妍熹,赵筱奕,赵絮琪,赵海艳,赵斯语,赵梅英,赵俊婷,赵才茹,赵舒畅,赵亚茹,赵恬语,赵艺楚,赵诗怡,赵忆琛,赵伟芬,赵美鑫,赵若诗,赵鑫媛,赵媛鑫,赵乃慧,赵洁鑫,赵若思,赵鑫洁,赵如诗,赵梅香,赵如思,赵若丝,赵广琴,赵叶雯,赵绮鑫,赵依雯,赵鑫莹,赵思仪,赵雅晴,赵春笑,赵鑫卉,赵鑫蕙,赵丽鑫,赵玲鑫,赵琳鑫,赵佩君,赵星慧,赵伟玲,赵悦然,赵婧妤,赵珺莉,赵筠莉,赵峻莉,赵浚莉,赵浚丽,赵浚俐,赵彩芳,赵谦雅,赵贤雅,赵谦影,赵璧儿,赵灵儿,赵新萍,赵淑慧,赵栖含,赵影萍,赵栖蕴,赵静莎,赵敬莎,赵曦颖,赵榕蕴,赵寒冰,赵羲颖,赵黎英,赵昕颖,赵希颖,赵蒙笑,赵蒙欣,赵萌笑,赵萌乐,赵惜颖,赵蒙萌,赵梓萌,赵筱蒙,赵茜颖,赵翕颖,赵煜萍,赵岚颖,赵兰颖,赵颖颖,赵盈盈,赵梦洁,赵紫菡,赵梦杰,赵雨菡,赵文瑛,赵玉瑛,赵紫瑛,赵芮萱,赵玉菡,赵平芝,赵瑞芝,赵贤芝,赵婧琦,赵贝贝,赵军霞,赵之侠,赵玉秋,赵文蕊,赵姝英,赵姝瑛,赵滢舒,赵玥淼,赵岚昀,赵靖芝,赵昀琪,赵靖茹,赵昀萱,赵新艳,赵兰峰,赵春娥,赵二翠,赵冬琦,赵雨朦,赵雨蒙,赵清妍,赵群媚,赵格畅,赵嘉琳,赵姝婷,赵艺扉,赵韵琳,赵屿彤,赵丹冰,赵彤屿,赵润琳,赵蕴涵,赵惠玲,赵雨楠,赵琬迪,赵馥琳,赵益兰,赵子菲,赵玉莹,赵乙潞,赵纯杉,赵梦伊,赵颖菲,赵晨芳,赵静菲,赵纯微,赵亦菲,赵辰菲,赵青敏,赵雅姿,赵芳敏,赵舆敏,赵英菲,赵乙涵,赵猗,赵紫贤,赵令菲,赵婉杉,赵韫金,赵文韫,赵婷菲,赵纯雯,赵莹爱,赵雅湘,赵岑茵,赵净,赵苓菱,赵睛,赵启玲,赵敬玲,赵文婕,赵璎萌,赵文珏,赵美荣,赵樱淇,赵舒帆,赵思楠,赵义琴,赵熠菲,赵萍玲,赵心彤,赵左洁,赵小珊,赵义芳,赵左婕,赵佐洁,赵溢蓉,赵梓茵,赵沂蓉,赵佐婕,赵溢溶,赵幸溶,赵溶依,赵羽亭,赵英睿,赵允琳,赵予绮,赵诗韵,赵弈茹,赵知琳,赵翊茹,赵若缺,赵翠翠,赵占莉,赵祺玥,赵娅冰,赵亚冰,赵乙彤,赵蕴茴,赵蔓茗,赵菲箐,赵韵寒,赵萩薇,赵霓芝,张梦琪,张筱宇,张可露,张竞予,张颖,张敏,张雅雯,张慧,张琇赑,张琇淼,张玉英,张茹,张馨予,张妍,张馨元,张馨方,张馨怡,张馨逸,张馨仪,张馨伊,张昕怡,张爱萍,张玉芳,张东丽,张玉兰,张笑宁,张小玉,张招英,张潇,张筠,张艺竞,张丽静,张卜鸾,张智雅,张瑞琪,张紫萱,张子萱,张善美,张智娟,张籽萱,张紫楦,张紫暄,张梓萱,张莹,张弦月,张蓝,张爱媛,张丽丽,张丙芳,张雯岚,张春柳,张钰涓,张伶妗,张瑶蓓,张琳,张玉馨,张窈嫒,张雪会,张正美,张馨月,张曼珂,张盈羽,张蕾明,张靖萱,张凯妍,张颜婷,张鹭,张译匀,张艾珂,张语彤,张延婷,张燕婷,张译予,张语桐,张艳婷,张冰蕊,张岩婷,张玮环,张媛苑,张丽洁,张馨宇,张言婷,张研婷,张心盈,张琰婷,张炎婷,张伟娟,张惠惠,张馨文,张飘,张欣语,张欣羽,张雨珂,张春燕,张晶婧,张语童,张语佟,张小芳,张小丽,张秋莲,张荟筠,张贝,张心怡,张若芸,张馨雨,张雨琪,张蓝月,张琪雨,张依彤,张苏瑶,张灿荧,张苏颖,张荟君,张若嫣,张荟郡,张紫琀,张卉郡,张绘郡,张芮,张子琀,张慧郡,张颖乙,张若雪,张钰淇,张惠郡,张智晴,张玉淇,张靓,张若晴,张姗娜,张采霞,张蕙郡,张婧,张仪雨,张若琪,张湉蕊,张恚捃,张玥,张湉心,张若音,张湉馨,张欢,张雪,张湉仪,张讳郡,张彩峡,张讳筠,张花玲,张讳隽,张若涵,张玉佳,张素云,张蕴蓥,张淑敏,张蕴萦,张圣玲,张昱瑶,张智瑶,张雅琪,张邰璇,张飒,张靓颖,张莎,张迎雪,张艺涵,张钥,张诗雨,张素君,张敬怡,张巧洁,张月菱,张伶,张朵,张国兰,张彦芳,张诗瑜,张月云,张诗怡,张梦涵,张梦欣,张影,张诗妤,张文静,张思桐,张思姚,张婧雯,张诗颖,张利娜,张铃,张雅苹,张惠,张椿燕,张巧稚,张铭淑,张沁浛,张贝瑶,张温馨,张英杰,张碧月,张译月,张春雨,张茹译,张叶雯,张立英,张笑,张娟花,张思沫,张晓倩,张美琪,张译心,张萍华,张旭晶,张舒沁,张沁韵,张韵沁,张书韵,张书沁,张艺榕,张画,张晓馥,张艺琼,张盈曦,张庆秀,张琳翊,张妮娟,张雨诺,张宁娟,张俊芳,张晓萍,张竞丹,张玲英,张彦萌,张晶馨,张晓雨,张赛琦,张翠雅,张玉慧,张俪曦,张雅琦,张珍宝,张孝菊,张思晗,张轺骊,张珺骊,张雪平,张妁,张梅玲,张瀚樱,张艺萌,张茗栾,张秀慧,张净,张潇缤,张芮曦,张钰萤,张小双,张钰妃,张宝琴,张佳羽,张姿,张妍姿,张艺歆,张汉娜,张楚蓠,张湘语,张建英,张雪晶,张霁倩,张筱竟,张卓茜,张韵,张书悦,张书瑶,张雪境,张林芳,张雅倩,张临芳,张晓雪,张湄姗,张朦月,张紫凝,张涵凝,张昕予,张雨含,张含裴,张钰荥,张向静,张盈盈,张庆玲,张业莹,张含因,张业蓉,张含婴,张梓伊,张含颖,张惠圆,张雪焦,张睿馥,张美琳,张悦优,张雨萌,张小凤,张兰芬,张立琴,张蓝分,张萌烨,张雨婷,张雪竹,张尹真,张苓翊,张月晶,张娈,张蒂,张艳荣,张卫芳,张尹倩,张斯羽,张萌昀,张巧,张馨笛,张思予,张以柔,张应琴,张恭兰,张雯予,张颖萌,张新颖,张露壬,张芸萌,张延霞,张旭慧,张萧尹,张嵛爱,张改娣,张艳霞,张惠芬,张苡菲,张雅星,张晏彤,张晏佳,张佳晏,张真花,张爱枝,张郦,张恋泯,张莲泯,张岚爱,张爱佳,张淑雅,张映荷,张溪茹,张敬茹,张筵朋,张朋筵,张诗青,张荑,张筵蕊,张筵芮,张柔婷,张译易,张筵栖,张译君,张筵晰,张筵溪,张爱云,张筵曦,张筵郗,张雯絮,张雯叙,张筵颉,张桂榕,张琛青,张梦娜,张娟鹏,张梦亭,张文菊,张静芳,张诗兰,张筵冬,张天馨,张玲梦,张茗寒,张秀丽,张珍瑜,张彤梦,张爱卿,张梦玲,张莎莎,张又砾,张容轩,张聪雅,张聪娅,张笑卿,张荔,张舒译,张筵格,张格筵,张晗涵,张筵彤,张桂卿,张晓萁,张靖晗,张语洋,张远萍,张朝娣,张琰萍,张晶淋,张璇,张淑芬,张烨涵,张凤麟,张诺焱,张炜婷,张焱诺,张韵奕,张县丽,张琳颉,张乃琚,张苏苏,张凤荣,张海丽,张奕涵,张彭媛,张洁贞,张筱筱,张小筱,张春英,张珈乐,张笑怡,张悦涵,张秀容,张碧连,张巧云,张建婷,张秋虹,张奕洁,张沅梦,张源梦,张金娣,张秀荣,张水芯,张水馨,张焕婷,张淑杰,张淑芹,张之菁,张之倩,张晰晴,张容伊,张宏丽,张苡荣,张苡露,张婷曦,张思侠,张贻茜,张苡馨,张思霞,张紫沐,张丁丹,张新月,张月英,张兰锁,张颖哲,张一萌,张雁溪,张岚瑛,张芮熙,张芮希,张一玫,张晓云,张秋梅,张小朋,张映月,张琀骊,张惠颖,张洁莹,张文琼,张军花,张巧韵,张巧芸,张芸,张煦晴,张舒,张永兰,张洪丽,张瑞玉,张梓潼,张王丽,张紫瑞,张予晗,张予涵,张可涵,张琼也,张守芬,张丹红,张聪敏,张语瞳,张锦月,张筱玲,张敏焰,张桠菽,张育梅,张可莹,张可盈,张小思,张云芳,张英芳,张云砾,张凤娇,张涵雅,张瑗,张小瑗,张一瑗,张一媛,张二媛,张姬,张欣玥,张书媛,张媛,张慧宇,张玲菱,张恬,张鑫蕾,张琬琬,张云媛,张先媛,张杰媛,张贤翠,张若兰,张雯鼎,张雯煜,张艺苔,张雯辉,张雯耀,张雯跃,张雯华,张书芳,张絮哲,张新菊,张永霞,张璞玥,张莺罂,张湘君,张雅芙,张树燕,张菊芹,张楚依,张径盈,张静怡,张巧瑛,张歆迪,张琬童,张菁涵,张美玉,张舒文,张琬郡,张梦晗,张笑函,张蔓瑶,张爱芝,张昆丽,张斯雯,张妤炯,张爱桐,张碧悦,张青桐,张妤亭,张沁彤,张琳艳,张译诺,张淑宇,张伊诺,张义珍,张淑雨,张惠媛,张旭莺,张旭瑛,张海蓉,张静菡,张婧菡,张倩楠,张菁菡,张东曼,张倩怡,张欣雨,张玲平,张翊筠,张翊倩,张琳力,张思语,张思昀,张又丹,张琬昱,张晓春,张旭姻,张歆,张旭缨,张语珊,张心兰,张新英,张雯琳,张玟琳,张嫘迩,张兆凤,张小琴,张鹤馨,张缠糯,张喏璐,张缠曦,张惠璞,张春霞,张子晶,张紫璐,张冬萍,张丁丽,张鹤丹,张丁莉,张艺杨,张威茹,张崴茹,张凤仙,张岱雯,张欣艾,张心爱,张力鳗,张雯淇,张含音,张辛怡,张露予,张微茹,张薇茹,张彩杰,张米淇,张真萍,张樱琼,张黛一,张米,张黛源,张喻露,张黛熙,张学艳,张黛怡,张黛妤,张了尹,张婷文,张妤熙,张雯露,张纯菁,张瑾晶,张海霞,张璠,张丽威,张湘佳,张滢淼,张恒美,张芯蕊,张玲华,张世慧,张瑞凤,张琳佳,张英舜,张祎甜,张怡甜,张季秋,张丹其,张祎恬,张丽慧,张静岩,张宝蓓,张淑烨,张丹奇,张洪梅,张钰桐,张佳湘,张馨媛,张湘梦,张桐菲,张淖翔,张文璐,张湘孜,张笑榕,张语潼,张靖雯,张冬菊,张若晗,张育娜,张灵,张雯舜,张家媛,张偌晗,张佼,张惠榕,张佼悦,张巧悦,张琼仙,张箬晗,张舒晨,张杰婷,张靖悦,张偌菡,张茉然,张鑫雅,张淑仙,张芮菡,张丝媛,张满红,张绮晗,张智仙,张毓琪,张利花,张爱华,张雁冰,张琳青,张芝华,张妃妃,张美美,张金瑶,张文警,张芝榕,张青春,张克娥,张紫奕,张克娟,张芸菁,张雨娜,张宇娜,张程茵,张语娜,张茵程,张冰俏,张晓艺,张潇涵,张冰柠,张桐俏,张冰晴,张潇湉,张薰今,张清雪,张玉童,张成梅,张玉涵,张潇琳,张曾弈,张曾谊,张曾熠,张曾宜,张润芳,张曾翊,张曾逸,张曾伊,张蕴潇,张姝玉,张雪琦,张闵琼,张净桐,张绣玲,张琬悦,张蕴蔷,张红岩,张运珍,张安霞,张雨诗,张黍娴,张容,张琪悦,张黍婵,张舒彤,张俏寒,张潇蔷,张书琳,张雨婕,张予婕,张筱淇,张琬敏,张双涵,张悦淇,张晓淇,张馨丹,张莉芬,张雅静,张晓侠,张慧华,张翠奉,张琬琪,张疏桐,张慧贞,张晓霞,张黍沁,张黍洁,张珏琪,张小霞,张娜瑛,张惠华,张黍涓,张寒微,张岚羽,张俪予,张琰莹,张才梅,张羽洁,张雨霏,张冰月,张金涵,张芹霞,张嘉伊,张亚春,张翊函,张函翊,张薇文,张思伽,张珍珍,张紫玉,张真瑜,张惠娴,张妤伊,张露瑶,张梦桃,张子蕊,张乐园,张作娟,张茗蕊,张逸舒,张巧婵,张晴雯,张素芹,张沁雅,张影祺,张荣珠,张苡柔,张娜祺,张霓,张汝雯,张嘉薇,张籍丹,张熠绮,张绮绮,张惠梅,张桂香,张婼宝,张丝嘉,张婷恣,张倩菲,张千菲,张芊菲,张沁菲,张沁帆,张沁凡,张沁范,张榕珈,张建珍,张黎娜,张忻瑶,张景红,张馨瑶,张羽菲,张心瑶,张菲晴,张菲蕾,张芷蕾,张靖菲,张靖晴,张璐桢,张清红,张彩芬,张菀莹,张芷莹,张辰菲,张渫晴,张雯杰,张涧晴,张菲凡,张荟冰,张菲帆,张菲梵,张宝芳,张保芳,张帆菲,张俪潆,张晓欢,张梓喃,张俊菊,张爱菊,张俊琴,张赛,张俊英,张蒙雪,张卜露,张孟雪,张玉鹃,张誉娟,张艳诚,张玉涓,张玫莹,张媚莹,张静轩,张一晴,张季月,张季语,张雅文,张晓霜,王唯依,王婷婷,王玲娟,王巍娟,王佁函,王帼玮,王婧懿,王蓦瑶,王英,王艳娇,王瑛,王云霞,王海英,王佛兰,王誉玲,王溪蕾,王佛瑶,王凤娇,王嘉琪,王华英,王畦芎,王文霞,王欣,王佳琪,王紫寒,王紫韩,王紫涵,王莎莎,王紫耘,王媛媛,王丹丹,王文琴,王雪蕊,王媛,王小燕,王泥,王漫,王静柔,王漫妮,王斐然,王漫霓,王洪霞,王漫旎,王漫呢,王黛毓,王晓漫,王朱琴,王倩倩,王聪妮,王紫聪,王淑莲,王邦雯,王巧玲,王留霞,王威洁,王馨田,王纳,王乔楠,王桂洋,王邦婕,王葑,王欣欣,王晓霞,王馨馨,王邦丽,王乔荟,王佳,王迦兰,王邦莉,王琴,王馨妍,王梅娥,王丹凤,王邦莎,王春婷,王邦倩,王姬月,王邦妹,王邦梅,王邦薇,王珊,王辰玥,王杰兰,王金花,王悦涵,王丽华,王亚萍,王邦蓉,王书莲,王雪琳,王倩茹,王倩如,王雁茹,王晓琳,王瑾,王新熳,王雅漩,王新慧,王国艳,王敬怡,王影,王凤霞,王欣怡,王洁,王靖雯,王真,王洁宁,王桂芝,王淑慧,王琳慧,王英坤,王美玲,王云舒,王淑华,王瑛琪,王晓菁,王保玲,王薇,王小语,王语,王艺珺,王玲玲,王宝玲,王榆婷,王静雯,王迎婷,王芝君,王馨怡,王晓楠,王楠,王钦玥,王珺娴,王子萱,王丽珊,王子璇,王纨,王子婵,王晓晶,王箐,王丹熠,王奕涵,王冬梅,王子娇,王馥瑞,王婕,王俊婕,王瑞兰,王琼,王姚伶,王子琼,王秋月,王智燕,王春月,王韶韵,王巧利,王惠,王艳花,王珏婷,王婉,王久娣,王艳洁,王俊婷,王昱霏,王景月,王婷玉,王景梅,王玉蓉,王妮颖,王艺囝,王韶婕,王心歌,王韶玥,王桂宁,王夏月,王美月,王天英,王艺融,王红梅,王慧蓉,王红月,王馨辰,王丹华,王华梅,王红云,王玲英,王境薇,王淑霞,王子鲜,王春丽,王晓娟,王星月,王舒然,王秋锦,王楠钰,王诗雅,王珊妹,王娟芳,王诗毓,王艾萍,王诗怡,王娃娃,王亚莉,王雅莉,王雅丽,王嘉玉,王雅利,王欣如,王贵英,王潇,王心如,王双双,王馨如,王溪铃,王佳钰,王玉静,王碧雪,王如艺,王鹛邡,王如怡,王巧灵,王如忆,王占香,王大珍,王占美,王茄霖,王雨欣,王占翠,王雨蒙,王美娟,王丽慧,王星语,王少虹,王金珠,王惠黎,王敏嘉,王君玉,王鹳央,王晓涵,王潇霄,王慧仪,王秀,王赛,王苏诺,王颖佳,王芮,王建仙,王佳颖,王苏钰,王巧英,王佳珂,王淑贵,王蓓,王灿蓓,王禹菡,王姝涵,王昱丹,王瑞菊,王蕴涵,王雪菡,王韵菡,王菡韵,王思蓓,王化英,王馨琦,王蒴,王雪晴,王莺桦,王曾泓,王静姝,王增彩,王风青,王泓曾,王欣静,王馨静,王小羽,王娅,王欣竞,王潇颖,王若羽,王茵芝,王盈淼,王潇莹,王小慧,王樱萱,王香涵,王香菏,王海珍,王婉晴,王一萱,王淑景,王馨茹,王淑平,王津芝,王茗萱,王舒馨,王晓莉,王虹苏,王僖玉,王金莲,王洁莹,王禹晴,王晓琴,王美茜,王语菲,王梦凡,王藤娟,王斐禾,王网娣,王藤容,王筱彦,王彦敏,王彦莲,王语麦,王俊霞,王旭瑶,王力香,王玲华,王羽晴,王艳波,王旖旎,王雪拽,王华兰,王伟玲,王远萍,王晓琪,王嘉歆,王茗,王金枝,王雨舒,王乐怡,王孓乜,王琦瑶,王伊瑶,王莉霞,王馨贤,王苗潇,王紫薇,王宏丽,王子雯,王栗梅,王子婴,王金芝,王兆珍,王梦佳,王紫雯,王欢欢,王应梅,王秀云,王婉仪,王颜,王卉彤,王佳芮,王斓菲,王虹蕾,王枘雨,王薇茜,王宝琴,王子歌,王媛曳,王华妮,王瑞梅,王佳昕,王乙伊,王童漩,王成艳,王悦然,王芬芬,王凤丹,王雪昕,王雪恬,王佳恬,王月恬,王荧,王鸿燕,王学玲,王小瑶,王恋,王霈雨,王秀粉,王秀美,王玉璠,王小娟,王馨宇,王星燕,王晓曦,王思佳,王英英,王丹梓,王思,王利英,王贞,王巍璇,王思斯,王莉红,王艳艳,王建英,王晨思,王丹蕊,王巧宁,王春红,王雪冰,王美媛,王亚男,王红果,王桂莲,王潇雅,王思怡,王斯诺,王思冰,王思苏,王斯琴,王琬,王常秀,王亦珊,王芳辉,王安霞,王佳茵,王绍莲,王盼兮,王格,王盼希,王盼曦,王文娟,王誉艳,王嘉潼,王芬,王小雨,王盼溪,王思飘,王宗艳,王昭雪,王岚,王子莉,王艳芬,王小雯,王梓丽,王尤玥,王一惠,王培珍,王梦兰,王静静,王锦鸽,王一菲,王璇玥,王小萌,王謦,王婉菁,王丽景,王奕凤,王朵朵,王蓉蓉,王籽烨,王润妍,王籽铃,王祈蓝,王依笑,王贵梅,王烨菲,王美琪,王虹烨,王恩蕊,王菲烨,王凤贵,王家兰,王美玉,王碧莲,王彦妮,王雅静,王冰芳,王家珍,王旃婴,王露瑾,王藜静,王惠丹,王歆月,王芯悦,王心悦,王改玲,王予舴,王羽潼,王羽桐,王丹艺,王艺潼,王含汶,王淑存,王世琴,王姝雯,王语晗,王世美,王楚潼,王佳旋,王歆洁,王远芳,王楚洁,王楚含,王红岩,王凤珍,王楚函,王雨烟,王烟雨,王伶丽,王伶利,王晨鹭,王静飞,王海娟,王唤清,王颖桦,王雅婕,王歆桐,王宇璐,王荟乐,王君蕊,王灵琴,王丽霞,王蔓辰,王蔓宸,王盼望,王蔓宇,王元芳,王蔓泽,王宇蔓,王伶莉,王籽柔,王籽妙,王彩云,王云菊,王净妃,王红琴,王墨涵,王黛宁,王顺琼,王予馨,王馨卉,王伶藜,王潇燕,王炳娟,王伶黎,王女馨,王怡欢,王伶郦,王海侠,王歆童,王耐花,王月蘅,王仪涵,王矜钥,王键蓉,王紫玥,王姝月,王爱宁,王茜宝,王叶瑶,王晓钰,王滢茔,王凤茹,王娅琳,王茔茔,王泺滢,王钰滢,王玉滢,王圆,王铄滢,王若嘉,王雪琴,王剑芳,王圆圆,王欣然,王微晞,王菁璠,王幸红,王思恬,王苗亦,王立静,王嘉怡,王德霞,王理微,王可悦,王理薇,王嗉凤,王才霞,王月露,王月淼,王雨柔,王乙晶,王乙露,王林露,王蕤,王玉露,王湘匀,王金露,王玺露,王妙玲,王敏捷,王世娟,王丽达,王昱苹,王婉萍,王梓艺,王艺萍,王利娟,王妤芊,王春懿,王与芊,王昱芊,王予易,王真希,王雅文,王梅珠,王月琪,王心羽,王靖琪,王春茜,王瑗琪,王媛琪,王艾琪,王艺童,王丽淑,王彦婕,王冬莲,王韵雅,王佳丽,王欣奕,王芷涵,王歆翌,王一男,王肇娟,王昭茜,王真茜,王孟妍,王丽惠,王宇馨,王浣西,王纤亦,王彩文,王嘉薪,王利芳,王艳飞,王梓媛,王雨寒,王子媛,王红雨,王悦兮,王桂红,王钰洁,王悦茜,王文娇,王朵菡,王钰淼,王淑征,王语墨,王桂荣,王秀娥,王彦芹,王米,王缘朋,王翎,王松燕,王栉烨,王奕丹,王瑞巧,王云丽,王碧桃,王松琴,王细霞,王秋香,王秀彦,王彦秀,王煜莹,王雪芹,王煜婷,王韵非,王煜莺,王芹,王密密,王蒽诺,王煜葶,王雅琦,王怀瑶,王草,王思瑜,王喜兰,王语彤,王彤彤,王金兰,王立玲,王思悦,王思桠,王韵斐,王筠鸿,王慧丽,王海晶,王琪蔚,王沁雯,王荠蔚,王淑志,王漪妃,王嘉韵,王淑璇,王志妍,王苡葶,王宇萱,王骊骊,王骊,王骊莉,王荔荔,王荔莉,王桂芬,王梨梨,王哩哩,王娴,王欣霏,王梦童,王慧英,王爱菊,王弈盈,王琇,王弈莹,王素萍,王钰茹,王纳文,王妞,王恬妞,王雅儒,王语心,王笑昀,王菲雪,王奕妍,王紫菲,王彦妍,王婧宇,王娉婷,王玉童,王伊诺,王嫣,王一珺,王溪媛,王雪媛,王婧宏,王美红,王艳敏,王婧宁,王婧帆,王尘香,王婧颖,王一卉,王薪欣,王紫璇,王庭凤,王欣妍,王骊元,王铱芳,王逸芳,王轶芳,王娇宁,王丽婧,王锦芳,王菁鹤,王梦迪,王笑涵,王宇琼,王璐祺,王艺涟,王冰瑶,王漪楠,王睛,王亚琛,王惠珺,王惠君,王惠丽,王惠琳,王思燕,王丽岚,王三红,王亚玲,王馨忆,王昱惠,王光雯,王慕白,王雪娇,王婧菲,王紫嫱,王昭容,王豆叮,王阅涵,王惜源,王懿珈,王月晗,王紫桐,王紫佟,王采妮,王又芬,王新雅,王舒雅,王燕妮,王又分,王海聆,王紫梓,王雯一,王当当,王姝雅,王含,王珂馨,王优优,王姿萱,王美雯,王孜萱,王丽市,王秀利,王秋花,王馨茉,王芷晴,王明香,王静妍,王凤斐,王靓妍,王煜玲,王菁妍,王静伟,王嘉玲,王肖冰,王肖红,王熙雯,王云闲,王宁忆,王闲云,王润眉,王芷瑜,王菁琰,王琫,王琫晖,王梓玥,王海雯,王菁嫣,王菁胭,王润梅,王菁焰,王静琰,王静嫣,王静胭,王婧琰,王婧焱,王静焱,王采清,王茹春,王欣蕊,王秀乡,王慧娟,王英兰,王静烟,王新芬,王琳茜,王婵,王育红,王中花,王雪萍,王均瑶,王建娥,王蕾镭,王橼香,王橼丹,王施,王丽欣,王美珍,王佳瑜,王茜婷,王佳心,王爱佳,王盼好,王雅雅,王珞彤,王世霞,王宁茜,王瑜茜,王苛茜,王珂茜,王屏,王胜娟,王嫦茜,王静如,王焱嫦,王彩嫦,王巧荣,王采嫦,王月嫦,王乃芸,王语昕,王睬嫦,王雯佳,王美祎,王静虹,王金荟,王小捧,王靖虹,王陈嫦,王良妍,王雪虹,王思蕊,王俊娴,王晓珊,王吴瑾,'
    str1 = str1.split(',')
    ming = []
    for i in str1:
        if i.startswith('赵'):
            ming.append(i[1:])
        if i.startswith('王'):
            ming.append(i[1:])
        if i.startswith('张'):
            ming.append(i[1:])

    print('\r\n\r\n名字：男孩（{}）'.format(len(jar_random.NAME_BODY_MING)))
    print(jar_random.NAME_BODY_MING)
    print('名字：女孩（{}）'.format(len(jar_random.NAME_GIRL_MING)))
    print(jar_random.NAME_GIRL_MING)

    str111 = '<div class="alert alert-error">Please enter some text first.</div>'
    print(str111.find('dashdjksahdj'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
@Time    ：2020/9/23 18:16
@Author  ：维斯
@File    ：tool_pro_path.py
@Version ：1.0
@Function：获取当前项目根路径
"""

import os


def get_project_path(project_name=None, print_log=False):
    """
    获取当前项目根路径
    :param project_name: 项目名称
                            1、可在调用时指定
                            2、[推荐]也可在此方法中直接指定 将'PyUtilityTool'替换为当前项目名称即可（调用时即可直接调用 不用给参数）
    :param print_log: 是否打印日志信息
    :return: 指定项目的根路径
    """
    p_name = 'PyUtilityTool' if project_name is None else project_name
    project_path = os.path.abspath(os.path.dirname(__file__))
    # Windows
    if project_path.find('\\') != -1: separator = '\\'
    # Mac、Linux、Unix
    if project_path.find('/') != -1: separator = '/'

    root_path = project_path[:project_path.find(f'{p_name}{separator}') + len(f'{p_name}{separator}')]
    if print_log: print(f'当前项目名称：{p_name}\r\n当前项目根路径：{root_path}')
    return root_path


if __name__ == '__main__':
    get_project_path()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
@Time    ：2020/8/10 9:25
@Author  ：维斯
@File    ：tool_json.py
@Version ：1.0
@Function：JSON工具
"""

import json


class PyUtilJson:
    @staticmethod
    def json_format(json_str, is_dict_str=False):
        """
        格式化JSON字符串
        :param json_str: 原始json字符串(双引号 非字典的单引号)
        :param is_dict_str: json_str是否是字典字符串
        :return: 格式化后的JSON字符串（JOSN格式形式）
        """
        # 验证是否是str类型
        if type(json_str) != str:
            json_str = str(json_str)
        # 若json_str是字典字符串
        if is_dict_str:
            json_str = json_str.replace('\'', '\"')
        json_str = json.loads(json_str)
        return json.dumps(json_str, sort_keys=True, indent=4, separators=(',', ':'), ensure_ascii=False)

    @staticmethod
    def get_params_to_json_params(get_params_str):
        """
        GET请求中的参数转换为JSON格式
        :param get_params_str:
        """
        """
        如：password=123456&tel=13675480983 转换为
        {
            "password": "123456",
            "tel": "13675480983"
        }
        """
        params = get_params_str.split('&')
        params_json = {}
        for count in range(len(params)):
            a = params[count].split('=')
            params_json[a[0]] = a[1]
        print(json.dumps(params_json, sort_keys=True, indent=4, separators=(',', ':'), ensure_ascii=False))
        return json.dumps(params_json)

    @staticmethod
    def json_params_to_get_params(json_params_str):
        """
        JSON格式/字典格式 转换为GET请求中的参数
        :param json_params_str:
        """
        """
        如：
        {
            "password": "123456",
            "tel": "13675480983"
        }
        转换为
        password=123456&tel=13675480983
        """
        # 判断是否是字符串类型
        if type(json_params_str) != str:
            json_params_str = str(json_params_str)
        # 字典字符串 转换 json字符串
        json_params = json_params_str.replace('\'', '\"')
        # json转换为字典
        dict_params = json.loads(json_params)
        get_params = ''
        for key, value in dict_params.items():
            get_params = '{}{}={}&'.format(get_params, key, value)
        # 去除最后一个‘&’
        get_params = get_params[:len(get_params) - 1]
        print(get_params)
        return get_params

    @staticmethod
    def header_to_json(header: str):
        """
        :param header:

        如：
        accept: */*\r\n\
        accept-encoding: gzip, deflate, br
        accept-language: zh-CN,zh;q=0.9
        content-length: 592
        content-type: application/json
        origin: https://hee.net
        referer: https://hee.net
        sec-fetch-dest: empty
        sec-fetch-mode: cors
        sec-fetch-site: same-site
        user-agent: Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1
        x-app-version: 1
        x-auth-token
        x-channel: H5
        x-client-ip: 1.1.1.1
        x-device-id: iOS|iPhone|Safari|605.115
        x-tenant-code: xxxx

        转为json格式
        {
            "accept":"*/*",
            "accept-encoding":"gzip, deflate, br",
            "accept-language":"zh-CN,zh;q=0.9",
            "content-length":"592",
            "content-type":"application/json",
            "origin":"https://hee.net",
            "referer":"https://hee.net",
            "sec-fetch-dest":"empty",
            "sec-fetch-mode":"cors",
            "sec-fetch-site":"same-site",
            "user-agent":"Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1",
            "x-app-version":"1",
            "x-auth-token":"",
            "x-channel":"H5",
            "x-client-ip":"1.1.1.1",
            "x-device-id":"iOS|iPhone|Safari|605.115",
            "x-tenant-code":"xxxx"
        }

        :return JOSN格式的请求头
        """
        header_json = {}
        # step1 获取每个header （\r\n区分）
        header_list = header.split('\r\n')
        for header in header_list:
            # 提取key、value
            h = header.split(': ')
            if len(h) == 1:
                h.append('')
            # 删除空格
            # h[0] = h[0].replace(' ', '')
            # h[1] = h[1].replace(' ', '')
            header_json[h[0]] = h[1]
        # JSON格式化
        json_str = PyUtilJson().json_format(str(header_json), True)
        print(json_str)
        return json_str


if __name__ == '__main__':
    str1 = 'password=123456&tel=13675480983'
    PyUtilJson().get_params_to_json_params(str1)

    string = {
        "password": "123456",
        "tel": "13675480983"
    }
    PyUtilJson().json_params_to_get_params(string)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
@Time    ：2020/8/20 21:02
@Author  ：维斯
@File    ：tool_excel.py
@Version ：1.0
@Function：Excel工具
"""

from typing import List

import xlwt


class PyUtilExcel:
    def __init__(self, header_list: List[list]):
        """
        :param header_list: 如下格式
            例1：默认列宽
            header_list = [
                ['序号'],    # 表格第0列[此列表头名称]
                ['姓名'],
                ['性别'],
                ['爱好'],
                ['生日']
            ]
            例2：自定义列宽（列宽值为int类型 英文字符长度 如：10 表示列宽为10个英文字符长度）
            header = [
                ['序号', 5],  # 表格第0列[此列表头名称,列宽]
                ['姓名', 10], # 表格第1列[此列表头名称,列宽]
                ['性别', 10],
                ['爱好', 10],
                ['生日', 20]
            ]
        """
        self.data = header_list
        self.__color_str = 'aqua 0x31\r\n\
black 0x08\r\n\
blue 0x0C\r\n\
blue_gray 0x36\r\n\
bright_green 0x0B\r\n\
brown 0x3C\r\n\
coral 0x1D\r\n\
cyan_ega 0x0F\r\n\
dark_blue 0x12\r\n\
dark_blue_ega 0x12\r\n\
dark_green 0x3A\r\n\
dark_green_ega 0x11\r\n\
dark_purple 0x1C\r\n\
dark_red 0x10\r\n\
dark_red_ega 0x10\r\n\
dark_teal 0x38\r\n\
dark_yellow 0x13\r\n\
gold 0x33\r\n\
gray_ega 0x17\r\n\
gray25 0x16\r\n\
gray40 0x37\r\n\
gray50 0x17\r\n\
gray80 0x3F\r\n\
green 0x11\r\n\
ice_blue 0x1F\r\n\
indigo 0x3E\r\n\
ivory 0x1A\r\n\
lavender 0x2E\r\n\
light_blue 0x30\r\n\
light_green 0x2A\r\n\
light_orange 0x34\r\n\
light_turquoise 0x29\r\n\
light_yellow 0x2B\r\n\
lime 0x32\r\n\
magenta_ega 0x0E\r\n\
ocean_blue 0x1E\r\n\
olive_ega 0x13\r\n\
olive_green 0x3B\r\n\
orange 0x35\r\n\
pale_blue 0x2C\r\n\
periwinkle 0x18\r\n\
pink 0x0E\r\n\
plum 0x3D\r\n\
purple_ega 0x14\r\n\
red 0x0A\r\n\
rose 0x2D\r\n\
sea_green 0x39\r\n\
silver_ega 0x16\r\n\
sky_blue 0x28\r\n\
tan 0x2F\r\n\
teal 0x15\r\n\
teal_ega 0x15\r\n\
turquoise 0x0F\r\n\
violet 0x14\r\n\
white 0x09\r\n\
yellow 0x0D'
        self.color_list = []  # [[]]   [['aqua', '0x31'], ['black', '0x08'], ...]
        for color in self.__color_str.split('\r\n'):
            color = color.split(' ')
            self.color_list.append(color)

    def write(self, out_file, data_body: List[list], sheet_name='sheet', frozen_row: int = 1, frozen_col: int = 0):
        """
        写入数据
        :param out_file: 保存文件（如：test.xlsx）
        :param data_body: data_body[0]为表格第0行数据  data_body[0][0]为表格第0行第0列单元格值
        :param sheet_name:
        :param frozen_row: 冻结行（默认首行）
        :param frozen_col: 冻结列（默认不冻结）
        """
        # step1 判断数据正确性（每行列数是否与表头相同）
        count = 0
        for pro in data_body:
            if len(pro) != len(self.data):
                raise Exception(
                    'data_body数据错误 第{}行（从0开始） 需为{}个元素 当前行{}个元素：{}'.format(count, len(self.data), len(pro), str(pro)))
            count += 1

        # step2 写入数据
        wd = xlwt.Workbook()
        sheet = wd.add_sheet(sheet_name)

        ali_horiz = 'align: horiz center'  # 水平居中
        ali_vert = 'align: vert center'  # 垂直居中
        fore_colour = 'pattern: pattern solid,fore_colour pale_blue'  # 设置单元格背景色为pale_blue色

        # 表头格式（垂直+水平居中、表头背景色）
        style_header = xlwt.easyxf('{};{};{}'.format(fore_colour, ali_horiz, ali_vert))

        # 表体格式（垂直居中）
        style_body = xlwt.easyxf('{}'.format(ali_vert))

        # 表头
        for col in self.data:
            # 默认列宽
            if len(col) == 1:
                sheet.write(0, self.data.index(col), str(col[0]), style_header)
            # 自定义列宽
            if len(col) == 2:
                sheet.write(0, self.data.index(col), str(col[0]), style_header)
                # 设置列宽
                sheet.col(self.data.index(col)).width = 256 * col[1]  # 256为基数 * n个英文字符
        # 行高（第0行）
        sheet.row(0).height_mismatch = True
        sheet.row(0).height = 20 * 20  # 20为基数 * 20榜

        # 表体
        index = 1
        for pro in data_body:
            sheet.row(index).height_mismatch = True
            sheet.row(index).height = 20 * 20  # 20为基数 * 20榜
            for d in self.data:
                value = pro[self.data.index(d)]
                # 若值类型是int、float 直接写入 反之 转成字符串写入
                if type(value) == int or type(value) == float:
                    sheet.write(index, self.data.index(d), value, style_body)
                else:
                    sheet.write(index, self.data.index(d), str(value), style_body)
            index += 1
        # 冻结（列与行）
        sheet.set_panes_frozen('1')
        sheet.set_horz_split_pos(frozen_row)  # 冻结前n行
        sheet.set_vert_split_pos(frozen_col)  # 冻结前n列

        wd.save(out_file)

    def color_test(self):
        """
        测试颜色
        """
        body_t = []
        for color in self.color_list:
            print(color)
            body_t.append(color)
        wd = xlwt.Workbook()
        sheet = wd.add_sheet('sheet')

        index = 0
        for b in body_t:
            ali = 'align: horiz center;align: vert center'  # 垂直居中 水平居中
            fore_colour = 'pattern: pattern solid,fore_colour {}'.format(
                self.color_list[index][0])  # 设置单元格背景色为pale_blue色
            style_header = xlwt.easyxf(
                '{};{}'.format(fore_colour, ali))
            sheet.write(index, 0, str(b), style_header)
            sheet.col(0).width = 256 * 150  # 256为基数 * n个英文字符
            index += 1

        wd.save('颜色测试.xlsx')


# 测试颜色
# if __name__ == '__main__':
#     header_t = [
#         ['颜色']
#     ]
#     JarExcelUtil(header_t).color_test()

if __name__ == '__main__':
    header = [
        ['序号', 5],
        ['姓名', 10],
        ['性别', 10],
        ['爱好', 10],
        ['生日', 20]
    ]

    # header = [
    #     ['序号'],
    #     ['姓名'],
    #     ['性别'],
    #     ['爱好'],
    #     ['生日']
    # ]

    body = [
        [1, '张三', '男', '篮球', '1994-07-23'],
        [2, '李四', '女', '足球', '1994-04-03'],
        [3, '王五', '男', '兵乓球', '1994-09-13']
    ]

    PyUtilExcel(header_list=header).write(out_file='测试.xlsx', data_body=body)
